#include	"ver.h"

#define	STR_SQUARE	"Home Circle"

#define	STR_EQUIP_WIELDING	"Wielding"
#define	STR_EQUIP_SHIELD	"Shield"
#define	STR_EQUIP_BOW	"Bow"
#define	STR_EQUIP_ARW	"Arw"
#define	STR_EQUIP_HEAD	"Head"
#define	STR_EQUIP_NECK	"Neck"
#define	STR_EQUIP_BODY	"Body"
#define	STR_EQUIP_ARM	"Arm"
#define	STR_EQUIP_RIGHT_HAND	"Right Hand"
#define	STR_EQUIP_LEFT_HAND	"Left Hand"
#define	STR_EQUIP_FEET	"Feet"
#define	STR_EQUIP_ABOUT_BODY	"About Body"
#define	STR_EQUIP_LIGHT_SOURCE	"Light Source"

#define	STR_DISARM	"Disarm"
#define	STR_GOLD	"GOLD"

#define	STR_FIG	"Fighter's Ability"
#define	STR_MON	"Monk's Ability"
#define	STR_HUN	"Hunter's Ability"
#define	STR_THI	"Thief's Ability"

#define	STR_MAG	"Magician's Ability"
#define	STR_SOR	"Sorcerer's Ability"
#define	STR_ENC	"Enchanter's Ability"
#define	STR_SUM	"Summoner's Ability"
#define	STR_PRI	"Priest's Ability"
#define	STR_SHA	"Shaman's Ability"
#define	STR_BAR	"Bard's Ability"
#define	STR_NIN	"Ninja's Ability"

	{ N_MSG_NULL,
		"" },
	{ N_MSG_NOT_NULL,
		" " },

	{ N_MSG_S,
		"%s" },

	{ N_MSG_GAME_NAME,
		STR_FILE_NAME_GAME },

	{ N_MSG_CANCEL,
		"You Canceled" },
	{ N_MSG_HIT_ANY_KEY,
		"- Hit any Key -" },
	{ N_MSG_HIT_ENTER_KEY,
		"- Hit [ENTER] Key -" },

	{ N_MSG_H_LINE,
		"-" },
	{ N_MSG_V_LINE,
		"|" },
	{ N_MSG_CROSS,
		"+" },
	{ N_MSG_H_FRAME,
		"----------------------------------------"
		"+---------------------------------------" },
	{ N_MSG_STAT_FRAME,
		"----------------------------------------" },

	{ N_MSG_SQUARE,
		STR_SQUARE },

	{ N_MSG_MORE,
		"-more-" },
	{ N_MSG_MORE_CLEAR,
		"      " },

	{ N_MSG_WAIT_KEY,
		"- Hit [ENTER] Key -" },

	{ N_MSG_INCOMPLETE,
		"This is Incomplete" },

	{ N_MSG_GAME_OVER,
		"Party was annihilated"
		"Hit [CTRL]+[Q]" },

	{ N_MSG_CHILD_PS,
		"Call %s\n" },

	{ N_MSG_OUT_MAP_FILE_1,
		"Input file name of map" },
	{ N_MSG_OUT_MAP_FILE_2,
		"Default '%s'" },
	{ N_MSG_OUT_MAP_FILE_3,
		"File name of map '%s'" },
	{ N_MSG_OUT_MAP_FILE_ASK_OK,
		"Do you want out put?" },

	{ N_MSG_MAIN_RACE_HUMAN,
		"Human" },
	{ N_MSG_MAIN_RACE_HALF_ELF,
		"Half Elf" },
	{ N_MSG_MAIN_RACE_ELF,
		"Elf" },
	{ N_MSG_MAIN_RACE_DWARF,
		"Dwarf" },
	{ N_MSG_MAIN_RACE_VIVID,
		"Vivid" },

	{ N_MSG_SUB_RACE_NULL,
		"Nothing" },
	{ N_MSG_SUB_RACE_CAT,
		"Cat" },
	{ N_MSG_SUB_RACE_DOG,
		"Dog" },
	{ N_MSG_SUB_RACE_MOUSE,
		"Mouse" },
	{ N_MSG_SUB_RACE_RABBIT,
		"Rabbit" },
	{ N_MSG_SUB_RACE_MONKEY,
		"Monkey" },
	{ N_MSG_SUB_RACE_PIG,
		"Pig" },
	{ N_MSG_SUB_RACE_BIRD,
		"Bird" },
	{ N_MSG_SUB_RACE_LIZARD,
		"Lizard" },

	{ N_MSG_RACE_NAME_VEGE,
		"Vege" },

	{ N_MSG_MALE,
		"Male" },
	{ N_MSG_FEMALE,
		"Female" },

	{ N_MSG_EQUIP_WIELDING,
		STR_EQUIP_WIELDING },
	{ N_MSG_EQUIP_SHIELD,
		STR_EQUIP_SHIELD },
	{ N_MSG_EQUIP_BOW,
		STR_EQUIP_BOW },
	{ N_MSG_EQUIP_ARW,
		STR_EQUIP_ARW },
	{ N_MSG_EQUIP_HEAD,
		STR_EQUIP_HEAD },
	{ N_MSG_EQUIP_NECK,
		STR_EQUIP_NECK },
	{ N_MSG_EQUIP_BODY,
		STR_EQUIP_BODY },
	{ N_MSG_EQUIP_ARM,
		STR_EQUIP_ARM },
	{ N_MSG_EQUIP_RIGHT_HAND,
		STR_EQUIP_RIGHT_HAND },
	{ N_MSG_EQUIP_LEFT_HAND,
		STR_EQUIP_LEFT_HAND },
	{ N_MSG_EQUIP_FEET,
		STR_EQUIP_FEET },
	{ N_MSG_EQUIP_ABOUT_BODY,
		STR_EQUIP_ABOUT_BODY },
	{ N_MSG_EQUIP_LIGHT_SOURCE,
		STR_EQUIP_LIGHT_SOURCE },

	{ N_MSG_STAT_DEAD,
		"Dead" },
	{ N_MSG_STAT_STONE,
		"Stone" },
	{ N_MSG_STAT_PARALYZE,
		"Paralyze" },
	{ N_MSG_STAT_POISON,
		"Poison" },
	{ N_MSG_STAT_CONFUSION,
		"Confusion" },
	{ N_MSG_STAT_BLIND,
		"Blind" },
	{ N_MSG_STAT_SLEEP,
		"Sleep" },
	{ N_MSG_STAT_SILENCE,
		"Silence" },
	{ N_MSG_STAT_FEAR,
		"Fear" },
	{ N_MSG_STAT_HALLUCINATION,
		"Hallucination" },
	{ N_MSG_STAT_CHARM,
		"Charm" },
	{ N_MSG_STAT_FLY,
		"Fly" },
	{ N_MSG_STAT_HUNGRY,
		"Hungry" },
	{ N_MSG_STAT_STARVATION,
		"Starvation" },
	{ N_MSG_STAT_FAINT,
		"Faint" },
	{ N_MSG_STAT_DRUNK,
		"Drunk" },

	{ N_MSG_ABL_NAME_HP,
		"HP" },
	{ N_MSG_ABL_NAME_MP,
		"MP" },
	{ N_MSG_ABL_NAME_DEX,
		"DEX" },
	{ N_MSG_ABL_NAME_STR,
		"STR" },
	{ N_MSG_ABL_NAME_AGI,
		"AGI" },
	{ N_MSG_ABL_NAME_WIS,
		"WIS" },
	{ N_MSG_ABL_NAME_INT,
		"INT" },
	{ N_MSG_ABL_NAME_CHA,
		"CHA" },
	{ N_MSG_ABL_NAME_FIG,
		"FIG" },
	{ N_MSG_ABL_NAME_MON,
		"MON" },
	{ N_MSG_ABL_NAME_HUN,
		"HUN" },
	{ N_MSG_ABL_NAME_THI,
		"THI" },
	{ N_MSG_ABL_NAME_MAG,
		"MAG" },
	{ N_MSG_ABL_NAME_SOR,
		"SOR" },
	{ N_MSG_ABL_NAME_ENC,
		"ENC" },
	{ N_MSG_ABL_NAME_SUM,
		"SUM" },
	{ N_MSG_ABL_NAME_PRI,
		"PRI" },
	{ N_MSG_ABL_NAME_SHA,
		"SHA" },
	{ N_MSG_ABL_NAME_BAR,
		"BAR" },
	{ N_MSG_ABL_NAME_NIN,
		"NIN" },

	{ N_MSG_CLASS_FIGHTER,
		"Fighter" },
	{ N_MSG_CLASS_MONK,
		"Monk" },
	{ N_MSG_CLASS_HUNTER,
		"Hunter" },
	{ N_MSG_CLASS_THIEF,
		"Thief" },
	{ N_MSG_CLASS_PRIEST,
		"Priest" },
	{ N_MSG_CLASS_SHAMAN,
		"Shaman" },
	{ N_MSG_CLASS_BARD,
		"Bard" },
	{ N_MSG_CLASS_WIZARD,
		"Wizard" },
	{ N_MSG_CLASS_SUMMONER,
		"Summoner" },
	{ N_MSG_CLASS_BISHOP,
		"Bishop" },

	{ N_MSG_MBR_DIE,
		"*** %s was dead ***" },

	{ N_MSG_EXP_PARTY,
		"All member get %ld EXP" },
	{ N_MSG_EXP_MBR,
		"%s gets %ld EXP" },
	{ N_MSG_LEV_UP,
		"*** %s was level up %s to %ld ***" },

	{ N_MSG_STAT_DUN_LEV_TTL_FLOOR,
		"Floor : " },
	{ N_MSG_STAT_DUN_LEV_TTL_BASE,
		"Base  : " },
	{ N_MSG_STAT_DUN_LEV_TTL_0,
		"Ground: " },

	{ N_MSG_NAME_BAR,
		"Bar" },
	{ N_MSG_NAME_INN,
		"Inn" },
	{ N_MSG_NAME_TEMPLE,
		"Temple" },
	{ N_MSG_NAME_WPN,
		"Wpn" },
	{ N_MSG_NAME_ARMOR,
		"Armor" },
	{ N_MSG_NAME_MAGIC,
		"Magic" },
	{ N_MSG_NAME_GROCERY,
		"Grocery" },
	{ N_MSG_NAME_RESTAURANT,
		"Restaurant" },
	{ N_MSG_NAME_TEAROOM,
		"Tearoom" },
	{ N_MSG_NAME_TOBACCO,
		"Tobacco" },

	{ N_MSG_AUTO_RELOAD,
		"%s done auto reload %s" },

	{ N_MSG_ATTACK_PUNCH,
		"%s punched %s" },
	{ N_MSG_ATTACK_KICK,
		"%s kicked %s" },
	{ N_MSG_ATTACK_BITE,
		"%s bited %s" },
	{ N_MSG_ATTACK_KNOCK,
		"%s knocked %s" },
	{ N_MSG_ATTACK_STING,
		"%s stinged %s" },
	{ N_MSG_ATTACK_SLASH,
		"%s slashed %s" },
	{ N_MSG_ATTACK_MOW,
		"%s mowed %s" },
	{ N_MSG_ATTACK_SHOOT,
		"%s shooted %s" },
	{ N_MSG_ATTACK_THROW,
		"%s throwed %s" },
	{ N_MSG_ATTACK_ERR,
		"Error of attack message" },
	{ N_MSG_FIGHT_CRTCL_STD,
		"%s is Critical Hit" },
	{ N_MSG_FIGHT_HIT_STD,
		"%s hitted %s to %d" },
	{ N_MSG_FIGHT_MISS_STD,
		"%s missed %s" },
	{ N_MSG_FIGHT_KILL_STD,
		"++XX %s killed %s XX++" },

	{ N_MSG_SPELL,
		"%s casted spell of %s" },

	{ N_MSG_TRGT_POS,
		"Position" },

	{ N_MSG_ACT_NULL,
		"" },
	{ N_MSG_ACT_MNSTR_FIGHT,
		"Fight" },
	{ N_MSG_ACT_MNSTR_THROW,
		"Throw" },
	{ N_MSG_ACT_MNSTR_TAIL,
		"Tail" },
	{ N_MSG_ACT_MBR_FIGHT,
		"Fight member" },
	{ N_MSG_ACT_MBR_THROW,
		"Throw member" },
	{ N_MSG_ACT_MBR_TAIL,
		"Tail member" },
	{ N_MSG_ACT_DOOR_OPEN,
		"Open door" },
	{ N_MSG_ACT_DOOR_CLOSE,
		"Close door" },
	{ N_MSG_ACT_DOOR_JAM,
		"Spike door" },
	{ N_MSG_ACT_DOOR_DISARM,
		STR_DISARM " door" },
	{ N_MSG_ACT_DOOR_BREAK,
		"Break door" },
	{ N_MSG_ACT_DOOR_PEEP,
		"Peep door" },
	{ N_MSG_ACT_DOOR_SRCH,
		"Detect door" },
	{ N_MSG_ACT_TRAP_DISARM,
		STR_DISARM "trap" },
	{ N_MSG_ACT_TRAP_BREAK,
		"Break trap" },
	{ N_MSG_ACT_TRAP_SRCH,
		"Detect trap" },
	{ N_MSG_ACT_ITEM_PICK_UP,
		"Pick up item" },
	{ N_MSG_ACT_ITEM_OPEN,
		"Open item" },
	{ N_MSG_ACT_ITEM_DISARM,
		STR_DISARM " item" },
	{ N_MSG_ACT_ITEM_BREAK,
		"Break item" },
	{ N_MSG_ACT_ITEM_SRCH,
		"Detect item" },
	{ N_MSG_ACT_ITEM_SEND,
		"Send item" },
	{ N_MSG_ACT_ITEM_DROP,
		"Drop item" },
	{ N_MSG_ACT_ITEM_RECEIVE,
		"Receive item" },
	{ N_MSG_ACT_POTION_QUAFF,
		"Quaff potion" },
	{ N_MSG_ACT_POTION_FILL,
		"Fill lamp with potion" },
	{ N_MSG_ACT_SCROLL_READ,
		"Read scroll" },
	{ N_MSG_ACT_STICK_ZAP,
		"Zap Stick" },
	{ N_MSG_ACT_FOOD_EAT,
		"Eat food" },
	{ N_MSG_ACT_TOBACCO_SMOKE,
		"Smoke Tobacco" },
	{ N_MSG_ACT_EQUIP,
		"Equip" },
	{ N_MSG_ACT_TAKE_OFF,
		"Take off" },
	{ N_MSG_ACT_EQUIP_MBR,
		"Equip other" },
	{ N_MSG_ACT_TAKE_OFF_MBR,
		"Take off other" },
	{ N_MSG_ACT_SRCH,
		"Search" },

/* ƥ */
	{ N_MSG_ITEM_UNKNOWN,
		"Υƥ" },

	{ N_MSG_ITEM_MJR_NAME_WEAPON,
		"Weapon" },
	{ N_MSG_ITEM_MJR_NAME_ARMOR,
		"Armor" },
	{ N_MSG_ITEM_MJR_NAME_POTION,
		"Potion" },
	{ N_MSG_ITEM_MJR_NAME_SCROLL,
		"Scroll" },
	{ N_MSG_ITEM_MJR_NAME_STICK,
		"Stick" },
	{ N_MSG_ITEM_MJR_NAME_ACCESSORY,
		"Accessory" },
	{ N_MSG_ITEM_MJR_NAME_FOOD,
		"Food" },
	{ N_MSG_ITEM_MJR_NAME_CHEST,
		"Chest" },
	{ N_MSG_ITEM_MJR_NAME_COIN,
		"Coin" },
	{ N_MSG_ITEM_MJR_NAME_GEM,
		"Gem" },
	{ N_MSG_ITEM_MJR_NAME_MISC,
		"Misc" },
	{ N_MSG_ITEM_MJR_NAME_ERR,
		"Unknown" },

	{ N_MSG_ITEM_MNR_NAME_SWORD,
		"Sword" },
	{ N_MSG_ITEM_MNR_NAME_BOW,
		"Bow" },
	{ N_MSG_ITEM_MNR_NAME_ARW,
		"Arw" },
	{ N_MSG_ITEM_MNR_NAME_STONE,
		"Stone" },
	{ N_MSG_ITEM_MNR_NAME_DAGGER,
		"Dagger" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_HEAD,
		"Armor Head" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_BODY,
		"Armor Body" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_ABOUT_BODY,
		"Armor About Body" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_ARM,
		"Armor Arm" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_SHIELD,
		"Armor Shield" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_FEET,
		"Armor Feet" },
	{ N_MSG_ITEM_MNR_NAME_POTION,
		"Potion" },
	{ N_MSG_ITEM_MNR_NAME_SCROLL,
		"Scroll" },
	{ N_MSG_ITEM_MNR_NAME_WAND,
		"Wand" },
	{ N_MSG_ITEM_MNR_NAME_ROD,
		"Rod" },
	{ N_MSG_ITEM_MNR_NAME_STAFF,
		"Staff" },
	{ N_MSG_ITEM_MNR_NAME_RING,
		"Ring" },
	{ N_MSG_ITEM_MNR_NAME_AMULET,
		"Amulet" },
	{ N_MSG_ITEM_MNR_NAME_NECKLACE,
		"Necklace" },
	{ N_MSG_ITEM_MNR_NAME_FOOD,
		"Food" },
	{ N_MSG_ITEM_MNR_NAME_CHEST,
		"Chest" },
	{ N_MSG_ITEM_MNR_NAME_COIN,
		"Coin" },
	{ N_MSG_ITEM_MNR_NAME_GEM,
		"Gem" },
	{ N_MSG_ITEM_MNR_NAME_LIGHT,
		"Light" },
	{ N_MSG_ITEM_MNR_NAME_SPIKE,
		"Spike" },
	{ N_MSG_ITEM_MNR_NAME_TOBACCO,
		"Tobacco" },
	{ N_MSG_ITEM_MNR_NAME_PIPE,
		"Pipe" },
	{ N_MSG_ITEM_MNR_NAME_JUNK,
		"Junk" },
	{ N_MSG_ITEM_MNR_NAME_ERR,
		"Unknown" },

/* Check Item Data */

	{ N_MSG_CHK_ITEM_DATA_NAME,
		"You detect %s" },
	{ N_MSG_CHK_ITEM_DATA_KIND,
		"This is %s" },
	{ N_MSG_CHK_ITEM_DATA_CAN_USE_MON,
		"You will fight with " STR_MON "(MON)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_MON,
		"if equip this then You will limit " STR_MON "(MON)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_THI,
		"if equip this then You will limit " STR_THI "(THI)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_MAG,
		"if equip this then You will limit " STR_MAG "(MAG)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_SOR,
		"if equip this then You will limit " STR_SOR "(SOR)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_ENC,
		"if equip this then You will limit " STR_ENC "(ENC)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_PRI,
		"if equip this then You will limit " STR_PRI "(PRI)" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_SHA,
		"if equip this then You will limit " STR_SHA "(SHA)" },

/*  */

	{ N_MSG_WPN_KNIFE,
		"Knife" },
	{ N_MSG_WPN_KRIS_KNIFE,
		"Kris knife" },
	{ N_MSG_WPN_MAIN_GAUCHE,
		"Main=Gauche" },
	{ N_MSG_WPN_SWORD_BREAKER,
		"Sword Breaker" },
	{ N_MSG_WPN_KATAR,
		"Katar" },
	{ N_MSG_WPN_JAMADHAR,
		"Jamadhar" },
	{ N_MSG_WPN_KUKRI,
		"Kukri" },

	{ N_MSG_WPN_SHORT_SWORD,
		"Short Sword" },
	{ N_MSG_WPN_GLADIUS,
		"Gladius" },

	{ N_MSG_WPN_LONG_SWORD,
		"Long Sword" },
	{ N_MSG_WPN_BROAD_SWORD,
		"Broad Sword" },
	{ N_MSG_WPN_CLAYMORE,
		"Claymore" },
	{ N_MSG_WPN_BASTARD_SWORD,
		"Bastard Sword" },
	{ N_MSG_WPN_GREAT_SWORD,
		"Great Sword" },

	{ N_MSG_WPN_SABRE,
		"Sabre" },
	{ N_MSG_WPN_SHAMSHIR,
		"Shamshir" },
	{ N_MSG_WPN_TALWAR,
		"Talwar" },
	{ N_MSG_WPN_FALCHION,
		"Falchion" },
	{ N_MSG_WPN_CUTLASS,
		"Cutlass" },
	{ N_MSG_WPN_SHOTEL,
		"Shotel" },
	{ N_MSG_WPN_KATANA,
		"Katana" },

	{ N_MSG_WPN_RAPIER,
		"Rapier" },
	{ N_MSG_WPN_ESTOC,
		"Estoc" },

	{ N_MSG_WPN_HAND_AXE,
		"Hand Axe" },
	{ N_MSG_WPN_FRANCISCA,
		"Francisca" },
	{ N_MSG_WPN_BHUJ,
		"Bhuj" },

	{ N_MSG_WPN_BATTLE_AXE,
		"Battle Axe" },
	{ N_MSG_WPN_BROAD_AXE,
		"Broad Axe" },
	{ N_MSG_WPN_GREAT_AXE,
		"Great Axe" },

	{ N_MSG_WPN_SPEAR,
		"Spear" },
	{ N_MSG_WPN_PILUM,
		"Pilum" },
	{ N_MSG_WPN_PIKE,
		"Pike" },
	{ N_MSG_WPN_JAVELIN,
		"Javelin" },
	{ N_MSG_WPN_TRIDENT,
		"Trident" },

	{ N_MSG_WPN_LANCE,
		"Lance" },

	{ N_MSG_WPN_WOODEN_CLUB,
		"Wooden Club" },
	{ N_MSG_WPN_QUARTER_STAFF,
		"Quarter Staff" },
	{ N_MSG_WPN_LIGHT_FLAIL,
		"Light Flail" },
	{ N_MSG_WPN_HEAVY_FLAIL,
		"Heavy Flail" },
	{ N_MSG_WPN_MORNINGSTAR,
		"Morningstar" },

	{ N_MSG_WPN_LIGHT_MACE,
		"Light Mace" },
	{ N_MSG_WPN_HEAVY_MACE,
		"Heavy Mace" },

	{ N_MSG_WPN_WAR_HAMMER,
		"War Hammer" },
	{ N_MSG_WPN_WAR_PICK,
		"War Pick" },
	{ N_MSG_WPN_ZAGHNOL,
		"Zaghnol" },
	{ N_MSG_WPN_BEC_DE_CORBIN,
		"Bec De Corbin" },

	{ N_MSG_WPN_PARTIZAN,
		"Partizan" },
	{ N_MSG_WPN_POLEAXE,
		"Poleaxe" },
	{ N_MSG_WPN_GLAIVE,
		"Glaive" },
	{ N_MSG_WPN_HALBERD,
		"Halberd" },
	{ N_MSG_WPN_CHAUVE_SOURIS,
		"Chauve Souris" },
	{ N_MSG_WPN_CORSESCA,
		"Corsesca" },
	{ N_MSG_WPN_SCYTHE,
		"Scythe" },
	{ N_MSG_WPN_FAUCHARD,
		"Fauchard" },
	{ N_MSG_WPN_GUISARME,
		"Guisarme" },

	{ N_MSG_WPN_BRASS_KNUCKLE,
		"Brass Knuckle" },
	{ N_MSG_WPN_BAGH_NAKH,
		"Bagh Nakh" },

	{ N_MSG_WPN_SLING,
		"Sling" },
	{ N_MSG_WPN_SHORT_BOW,
		"Short Bow" },
	{ N_MSG_WPN_LONG_BOW,
		"Long Bow" },
	{ N_MSG_WPN_COMPOSITE_BOW,
		"Composite Bow" },
	{ N_MSG_WPN_LIGHT_CROSS_BOW,
		"Light Cross Bow" },
	{ N_MSG_WPN_HEAVY_CROSS_BOW,
		"Heavy Cross Bow" },
	{ N_MSG_WPN_BLOW_GUN,
		"Blow Gun" },

	{ N_MSG_WPN_STONE,
		"Stone" },
	{ N_MSG_WPN_BULLET,
		"Bullet" },
	{ N_MSG_WPN_ARW,
		"Arw" },
	{ N_MSG_WPN_BOLT,
		"Bolt" },
	{ N_MSG_WPN_NEEDLE,
		"Needle" },

	{ N_MSG_WPN_DAGGER,
		"Dagger" },
	{ N_MSG_WPN_DARTS,
		"Darts" },
	{ N_MSG_WPN_SHURIKEN,
		"Shuriken" },
	{ N_MSG_WPN_BOOMERANG,
		"Boomerang" },

/* ɶ */

	{ N_MSG_ARMOR_LEATHER_CAP,
		"Leather Cap" },
	{ N_MSG_ARMOR_METAL_CAP,
		"Metal Cap" },
	{ N_MSG_ARMOR_SALLET,
		"Sallet" },
	{ N_MSG_ARMOR_CLOSE_HELMET,
		"Close Helmet" },
	{ N_MSG_ARMOR_SILVER_CROWN,
		"Silver Crown" },
	{ N_MSG_ARMOR_GOLDEN_CROWN,
		"Golden Crown" },
	{ N_MSG_ARMOR_JEWELED_CROWN,
		"Jeweled Crown" },

	{ N_MSG_ARMOR_ROBE,
		"Robe" },
	{ N_MSG_ARMOR_SOFT_LEATHER_ARMOR,
		"Soft Leather Armor" },
	{ N_MSG_ARMOR_HARD_LEATHER_ARMOR,
		"Hard Leather Armor" },
	{ N_MSG_ARMOR_RING_MAIL,
		"Ring Mail" },
	{ N_MSG_ARMOR_SCALE_MAIL,
		"Scale Mail" },
	{ N_MSG_ARMOR_DRAGON_SCALE,
		"Dragon Scale" },
	{ N_MSG_ARMOR_LAMELLAR_ARMOR,
		"Lamellar Armor" },
	{ N_MSG_ARMOR_CHAIN_MAIL,
		"Chain Mail" },
	{ N_MSG_ARMOR_MITHRIL_CHAIN,
		"Mithril Chain" },
	{ N_MSG_ARMOR_PLATE_ARMOR,
		"Plate Armor" },

	{ N_MSG_ARMOR_CLOAK,
		"Cloak" },

	{ N_MSG_ARMOR_LEATHER_GLOVES,
		"Leather Gloves" },
	{ N_MSG_ARMOR_GAUNTLETS,
		"Gauntlets" },

	{ N_MSG_ARMOR_LEATHER_BOOTS,
		"Leather Boots" },
	{ N_MSG_ARMOR_GREAVE,
		"Greave" },

	{ N_MSG_ARMOR_BUCKLER_SHIELD,
		"Buckler Shield" },
	{ N_MSG_ARMOR_ROUND_SHIELD,
		"Round Shield" },
	{ N_MSG_ARMOR_KITE_SHIELD,
		"Kite Shield" },
	{ N_MSG_ARMOR_HEATER_SHIELD,
		"Heater Shield" },

/* Potion */

	{ N_MSG_POTION_WATER,
		"Water" },
	{ N_MSG_POTION_MILK,
		"Milk" },
	{ N_MSG_POTION_WHITE_WINE,
		"White Wine" },
	{ N_MSG_POTION_RED_WINE,
		"Red Wine" },
	{ N_MSG_POTION_ROSE_WINE,
		"Rose Wine" },
	{ N_MSG_POTION_ALE,
		"Ale" },
	{ N_MSG_POTION_BRANDY,
		"Brandy" },
	{ N_MSG_POTION_RUM,
		"Rum" },
	{ N_MSG_POTION_COFFE,
		"Coffe" },
	{ N_MSG_POTION_ICE_COFFE,
		"Ice Coffe" },
	{ N_MSG_POTION_TEA,
		"Tea" },
	{ N_MSG_POTION_MILK_TEA,
		"Milk Tea" },
	{ N_MSG_POTION_LEMON_TEA,
		"Lemon Tea" },
	{ N_MSG_POTION_ICE_TEA,
		"Ice Tea" },
	{ N_MSG_POTION_ICE_MILK_TEA,
		"Ice Milk Tea" },
	{ N_MSG_POTION_ICE_LEMON_TEA,
		"Ice Lemon Tea" },
	{ N_MSG_POTION_APPLE_JUICE,
		"Apple Juice" },
	{ N_MSG_POTION_GRAPE_JUICE,
		"Grape Juice" },
	{ N_MSG_POTION_ORANGE_JUICE,
		"Orange Juice" },
	{ N_MSG_POTION_BLACK_BERRY_JUICE,
		"Black Berry Juice" },
	{ N_MSG_POTION_CRAN_BERRY_JUICE,
		"Cran Berry Juice" },
	{ N_MSG_POTION_RASP_BERRY_JUICE,
		"Rasp Berry Juice" },
	{ N_MSG_POTION_STRAW_BERRY_JUICE,
		"Straw Berry Juice" },
	{ N_MSG_POTION_OIL,
		"Oil" },
	{ N_MSG_POTION_STONE,
		"Potion of Stone" },
	{ N_MSG_POTION_PARALYZE,
		"Potion of Paralyze" },
	{ N_MSG_POTION_POISON,
		"Potion of Poison" },
	{ N_MSG_POTION_CONFUSION,
		"Potion of Confusion" },
	{ N_MSG_POTION_BLIND,
		"Potion of Blind" },
	{ N_MSG_POTION_SLEEP,
		"Potion of Sleep" },
	{ N_MSG_POTION_SILENCE,
		"Potion of Silence" },
	{ N_MSG_POTION_FEAR,
		"Potion of Fear" },
	{ N_MSG_POTION_HALLUCINATION,
		"Potion of Hallucination" },
	{ N_MSG_POTION_CHARM,
		"Potion of Charm" },
	{ N_MSG_POTION_FLY,
		"Potion of FLY" },
	{ N_MSG_POTION_VANISH,
		"Potion of VANISH" },
	{ N_MSG_POTION_CURE_LEV,
		"Potion of Cure Lev" },
	{ N_MSG_POTION_CURE_HP_LIGHT,
		"Potion of Cure Hp Light" },
	{ N_MSG_POTION_CURE_HP_MODERATE,
		"Potion of Cure Hp Moderate" },
	{ N_MSG_POTION_CURE_HP_SERIOUS,
		"Potion of Cure Hp Serious" },
	{ N_MSG_POTION_CURE_HP_MAX,
		"Potion of Cure Hp Max" },
	{ N_MSG_POTION_CURE_POISON,
		"potion of CURE Poison" },
	{ N_MSG_POTION_CURE_STATUS,
		"Potion of Cure Status" },
	{ N_MSG_POTION_RESI_PHYS,
		"Potion of Resi Phys" },
	{ N_MSG_POTION_RESI_HEAT,
		"Potion of Resi Heat" },
	{ N_MSG_POTION_RESI_COLD,
		"Potion of Resi Cold" },
	{ N_MSG_POTION_RESI_WIND,
		"Potion of Resi Wind" },
	{ N_MSG_POTION_RESI_ACID,
		"Potion of Resi Acid" },
	{ N_MSG_POTION_RESI_ELEC,
		"Potion of Resi Elec" },
	{ N_MSG_POTION_RESI_POIS,
		"Potion of Resi Pois" },
	{ N_MSG_POTION_SHARPNESS,
		"Potion of Sharpness" },
	{ N_MSG_POTION_DULLNESS,
		"Potion of Dullness" },
	{ N_MSG_POTION_STRENGTH,
		"Potion of Strength" },
	{ N_MSG_POTION_WEAKNESS,
		"Potion of Weakness" },
	{ N_MSG_POTION_QUICKNESS,
		"Potion of Quickness" },
	{ N_MSG_POTION_SLOWNESS,
		"Potion of Slowness" },
	{ N_MSG_POTION_WISE,
		"Potion of Wise" },
	{ N_MSG_POTION_FOOLISH,
		"Potion of Foolish" },
	{ N_MSG_POTION_BRAINY,
		"Potion of Brainy" },
	{ N_MSG_POTION_BRAINLESS,
		"Potion of Brainless" },
	{ N_MSG_POTION_ATTRACTIVE,
		"Potion of Attractive" },
	{ N_MSG_POTION_UNATTRACTIVE,
		"Potion of Unattractive" },
	{ N_MSG_POTION_SENSE_INVISIBLE,
		"Potion of Sense_INVISIBLE" },
	{ N_MSG_POTION_POW_UP_HP,
		"Potion of Pow Up HP" },
	{ N_MSG_POTION_SPEED_UP,
		"Potion of Speed Up" },
	{ N_MSG_POTION_SPEED_DOWN,
		"Potion of Speed Down" },
	{ N_MSG_POTION_DETECT_MNSTR,
		"Potion of Detect Mnstr" },

	{ N_MSG_POTION_COLOR_CRYSTAL,
		"Crystal" },
	{ N_MSG_POTION_COLOR_CRYSTAL_WHITE,
		"Crystal White" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BLACK,
		"Crystal Black" },
	{ N_MSG_POTION_COLOR_CRYSTAL_RED,
		"Crystal Red" },
	{ N_MSG_POTION_COLOR_CRYSTAL_GREEN,
		"Crystal Green" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BLUE,
		"Crystal Blue" },
	{ N_MSG_POTION_COLOR_CRYSTAL_YELLOW,
		"Crystal Yellow" },
	{ N_MSG_POTION_COLOR_CRYSTAL_RED_PURPLE,
		"Crystal Red Purple" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BLUE_PURPLE,
		"Crystal Blue Purple" },
	{ N_MSG_POTION_COLOR_CRYSTAL_ORANGE,
		"Crystal Orange" },
	{ N_MSG_POTION_COLOR_CRYSTAL_PINK,
		"Crystal Pink" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BROWN,
		"Crystal Brown" },
	{ N_MSG_POTION_COLOR_WHITE,
		"White" },
	{ N_MSG_POTION_COLOR_BLACK,
		"Black" },
	{ N_MSG_POTION_COLOR_RED,
		"Red" },
	{ N_MSG_POTION_COLOR_GREEN,
		"Green" },
	{ N_MSG_POTION_COLOR_BLUE,
		"Blue" },
	{ N_MSG_POTION_COLOR_YELLOW,
		"Yellow" },
	{ N_MSG_POTION_COLOR_RED_PURPLE,
		"Red Purple" },
	{ N_MSG_POTION_COLOR_BLUE_PURPLE,
		"Blue Purple" },
	{ N_MSG_POTION_COLOR_ORANGE,
		"Orange" },
	{ N_MSG_POTION_COLOR_PINK,
		"Pink" },
	{ N_MSG_POTION_COLOR_BROWN,
		"Brown" },
	{ N_MSG_POTION_COLOR_LUMINOUS_WHITE,
		"Luminous White" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BLACK,
		"Luminous Black" },
	{ N_MSG_POTION_COLOR_LUMINOUS_RED,
		"Luminous Red" },
	{ N_MSG_POTION_COLOR_LUMINOUS_GREEN,
		"Luminous Green" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BLUE,
		"Luminous Blue" },
	{ N_MSG_POTION_COLOR_LUMINOUS_YELLOW,
		"Luminous Yellow" },
	{ N_MSG_POTION_COLOR_LUMINOUS_RED_PURPLE,
		"Luminous Red Purple" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BLUE_PURPLE,
		"Luminous Blue Purple" },
	{ N_MSG_POTION_COLOR_LUMINOUS_ORANGE,
		"Luminous Orange" },
	{ N_MSG_POTION_COLOR_LUMINOUS_PINK,
		"Luminous Pink" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BROWN,
		"Luminous Brown" },
	{ N_MSG_POTION_COLOR_SPOTTED_WHITE,
		"Spotted White" },
	{ N_MSG_POTION_COLOR_SPOTTED_BLACK,
		"Spotted Black" },
	{ N_MSG_POTION_COLOR_SPOTTED_RED,
		"Spotted Red" },
	{ N_MSG_POTION_COLOR_SPOTTED_GREEN,
		"Spotted Green" },
	{ N_MSG_POTION_COLOR_SPOTTED_BLUE,
		"Spotted Blue" },
	{ N_MSG_POTION_COLOR_SPOTTED_YELLOW,
		"Spotted Yellow" },
	{ N_MSG_POTION_COLOR_SPOTTED_RED_PURPLE,
		"Spotted Red Purple" },
	{ N_MSG_POTION_COLOR_SPOTTED_BLUE_PURPLE,
		"Spotted Blue Purple" },
	{ N_MSG_POTION_COLOR_SPOTTED_ORANGE,
		"Spotted Orange" },
	{ N_MSG_POTION_COLOR_SPOTTED_PINK,
		"Spotted Pink" },
	{ N_MSG_POTION_COLOR_SPOTTED_BROWN,
		"Spotted Brown" },
	{ N_MSG_POTION_COLOR_MILK,
		"Milk" },
	{ N_MSG_POTION_COLOR_WHITE_WINE,
		"White Wine" },
	{ N_MSG_POTION_COLOR_RED_WINE,
		"Red Wine" },
	{ N_MSG_POTION_COLOR_ROSE_WINE,
		"Rose Wine" },
	{ N_MSG_POTION_COLOR_ALE,
		"Ale" },
	{ N_MSG_POTION_COLOR_BRANDY,
		"Brandy" },
	{ N_MSG_POTION_COLOR_RUM,
		"Rum" },
	{ N_MSG_POTION_COLOR_COFFE,
		"Coffe" },
	{ N_MSG_POTION_COLOR_ICE_COFFE,
		"Ice Coffe" },
	{ N_MSG_POTION_COLOR_TEA,
		"Tea" },
	{ N_MSG_POTION_COLOR_MILK_TEA,
		"Milk Tea" },
	{ N_MSG_POTION_COLOR_LEMON_TEA,
		"Lemon Tea" },
	{ N_MSG_POTION_COLOR_ICE_TEA,
		"Ice Tea" },
	{ N_MSG_POTION_COLOR_ICE_MILK_TEA,
		"Ice Milk Tea" },
	{ N_MSG_POTION_COLOR_ICE_LEMON_TEA,
		"Ice Lemon Tea" },
	{ N_MSG_POTION_COLOR_APPLE_JUICE,
		"Apple Juice" },
	{ N_MSG_POTION_COLOR_GRAPE_JUICE,
		"Grape Juice" },
	{ N_MSG_POTION_COLOR_ORANGE_JUICE,
		"Orange Juice" },
	{ N_MSG_POTION_COLOR_BLACK_BERRY_JUICE,
		"Black Berry Juice" },
	{ N_MSG_POTION_COLOR_CRAN_BERRY_JUICE,
		"Cran Berry Juice" },
	{ N_MSG_POTION_COLOR_RASP_BERRY_JUICE,
		"Rasp Berry Juice" },
	{ N_MSG_POTION_COLOR_STRAW_BERRY_JUICE,
		"Straw Berry Juice" },

/* Scroll */

	{ N_MSG_SCROLL_SLEEP,
		"Scroll of Sleep" },
	{ N_MSG_SCROLL_IDENTIFY_ITEM,
		"Scroll of Identify Item" },
	{ N_MSG_SCROLL_DETECT_ITEM,
		"Scroll of Detect Item" },
	{ N_MSG_SCROLL_TELEPORT,
		"Scroll of Teleport" },
	{ N_MSG_SCROLL_POW_UP_WPN_HIT,
		"Scroll of Power Up Weapon HIT" },
	{ N_MSG_SCROLL_POW_UP_WPN_DAM,
		"Scroll of Power Up Weapon DAM" },
	{ N_MSG_SCROLL_REMOVE_CURSE,
		"Scroll of Remove Curse" },
	{ N_MSG_SCROLL_RECALL,
		"Scroll of Recall" },

	{ N_MSG_READ_SCROLL_FAILURE,
		"%s can't read scroll because around is darkness" },

	{ N_MSG_SCROLL_TTL_SYLLABLE_DIV,
		"-" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_000,
		"A" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_001,
		"IN" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_002,
		"THE" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_010,
		"ON" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_011,
		"KIRI-KIRI" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_012,
		"BASARA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_013,
		"NHATTA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_020,
		"ABURA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_021,
		"KADABURA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_030,
		"BIBIDE" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_031,
		"BABIDE" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_032,
		"BOO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_040,
		"SYO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_041,
		"GYO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_042,
		"MUJOU" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_050,
		"NAM" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_051,
		"AMIDA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_052,
		"BUTSU" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_060,
		"KESERAN" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_061,
		"PASARAN" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_070,
		"ERO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_071,
		"IMM" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_072,
		"ESSAIM" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_080,
		"MINO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_081,
		"MON" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_082,
		"TA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_090,
		"KUKKU" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_091,
		"DODORU" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_092,
		"DOO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_101,
		"YUNA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_102,
		"DABU" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_103,
		"TRAY" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_104,
		"TETO" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_110,
		"HIKI" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_111,
		"REKI" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_120,
		"KESERA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_121,
		"SERA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_130,
		"ENNYA" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_131,
		"KORYA" },

/* Stick */

	{ N_MSG_STICK_FAILURE,
		"ʤˤⵯʤä" },

	{ N_MSG_STICK_MATERIAL_APPLEWOOD,
		"Applewood" },
	{ N_MSG_STICK_MATERIAL_ASHEN,
		"Ashen" },
	{ N_MSG_STICK_MATERIAL_ASPEN,
		"Aspen" },
	{ N_MSG_STICK_MATERIAL_AVOCADO_WOOD,
		"Avocado Wood" },
	{ N_MSG_STICK_MATERIAL_BALSA,
		"Balsa" },
	{ N_MSG_STICK_MATERIAL_BANYAN,
		"Banyan" },
	{ N_MSG_STICK_MATERIAL_BIRCH,
		"Birch" },
	{ N_MSG_STICK_MATERIAL_CEDAR,
		"Cedar" },
	{ N_MSG_STICK_MATERIAL_CHERRYWOOD,
		"Cherrywood" },
	{ N_MSG_STICK_MATERIAL_COTTONWOOD,
		"Cottonwood" },
	{ N_MSG_STICK_MATERIAL_CYPRESS,
		"Cypress" },
	{ N_MSG_STICK_MATERIAL_DOGWOOD,
		"Dogwood" },
	{ N_MSG_STICK_MATERIAL_DRIFTWOOD,
		"Driftwood" },
	{ N_MSG_STICK_MATERIAL_EBONY,
		"Ebony" },
	{ N_MSG_STICK_MATERIAL_ELM_WOOD,
		"Elm Wood" },
	{ N_MSG_STICK_MATERIAL_EUCALYPTUS,
		"Eucalyptus" },
	{ N_MSG_STICK_MATERIAL_GRAPEVINE,
		"Grapevine" },
	{ N_MSG_STICK_MATERIAL_HAWTHORN,
		"Hawthorn" },
	{ N_MSG_STICK_MATERIAL_HEMLOCK,
		"Hemlock" },
	{ N_MSG_STICK_MATERIAL_HICKORY,
		"Hickory" },
	{ N_MSG_STICK_MATERIAL_JUNIPER,
		"Juniper" },
	{ N_MSG_STICK_MATERIAL_LOCUST,
		"Locust" },
	{ N_MSG_STICK_MATERIAL_MAHOGANY,
		"Mahogany" },
	{ N_MSG_STICK_MATERIAL_MAGNOLIA,
		"Magnolia" },
	{ N_MSG_STICK_MATERIAL_MAPLE,
		"Maple" },
	{ N_MSG_STICK_MATERIAL_MULBERRY,
		"Mulberry" },
	{ N_MSG_STICK_MATERIAL_OAK,
		"Oak" },
	{ N_MSG_STICK_MATERIAL_PECAN,
		"Pecan" },
	{ N_MSG_STICK_MATERIAL_PERSIMMON,
		"Persimmon" },
	{ N_MSG_STICK_MATERIAL_PINE,
		"Pine" },
	{ N_MSG_STICK_MATERIAL_REDWOOD,
		"Redwood" },
	{ N_MSG_STICK_MATERIAL_ROSEWOOD,
		"Rosewood" },
	{ N_MSG_STICK_MATERIAL_SPRUCE,
		"Spruce" },
	{ N_MSG_STICK_MATERIAL_SUMAC,
		"Sumac" },
	{ N_MSG_STICK_MATERIAL_SYCAMORE,
		"Sycamore" },
	{ N_MSG_STICK_MATERIAL_TEAK,
		"Teak" },
	{ N_MSG_STICK_MATERIAL_WALNUT,
		"Walnut" },

/* Accecery */

	{ N_MSG_RING_SLOW_DIGESTION,
		"Ring of Slow Digestion" },
	{ N_MSG_RING_TELEPORT_PARTY,
		"Ring of Teleport Party" },
	{ N_MSG_RING_TELEPORT,
		"Ring of Teleport" },
	{ N_MSG_AMULET_RESI_PHYS,
		"Amulet of Resist PHYS" },
	{ N_MSG_AMULET_RESI_HEAT,
		"Amulet of Resist HEAT" },
	{ N_MSG_AMULET_RESI_COLD,
		"Amulet of Resist COLD" },
	{ N_MSG_AMULET_RESI_WIND,
		"Amulet of Resist WIND" },
	{ N_MSG_AMULET_RESI_ACID,
		"Amulet of Resist ACID" },
	{ N_MSG_AMULET_RESI_ELEC,
		"Amulet of Resist ELEC" },
	{ N_MSG_AMULET_RESI_POIS,
		"Amulet of Resist POIS" },

	{ N_MSG_RING_MATERIAL_ALUMINUM,
		"Aluminum" },
	{ N_MSG_RING_MATERIAL_BONE,
		"Bone" },
	{ N_MSG_RING_MATERIAL_BRASS,
		"Brass" },
	{ N_MSG_RING_MATERIAL_BRONZE,
		"Bronze" },
	{ N_MSG_RING_MATERIAL_CAST_IRON,
		"Cast_IRON" },
	{ N_MSG_RING_MATERIAL_CHROMIUM,
		"Chromium" },
	{ N_MSG_RING_MATERIAL_COPPER,
		"Copper" },
	{ N_MSG_RING_MATERIAL_GOLD,
		"Gold" },
	{ N_MSG_RING_MATERIAL_IRON,
		"Iron" },
	{ N_MSG_RING_MATERIAL_LEAD,
		"Lead" },
	{ N_MSG_RING_MATERIAL_MAGNESIUM,
		"Magnesium" },
	{ N_MSG_RING_MATERIAL_MOLYBDENUM,
		"Molybdenum" },
	{ N_MSG_RING_MATERIAL_NICKEL,
		"Nickel" },
	{ N_MSG_RING_MATERIAL_PEWTER,
		"Pewter" },
	{ N_MSG_RING_MATERIAL_SILVER,
		"Silver" },
	{ N_MSG_RING_MATERIAL_STEEL,
		"Steel" },
	{ N_MSG_RING_MATERIAL_TIN,
		"Tin" },
	{ N_MSG_RING_MATERIAL_TITANIUM,
		"Titanium" },
	{ N_MSG_RING_MATERIAL_TUNGSTEN,
		"Tungsten" },
	{ N_MSG_RING_MATERIAL_ZINC,
		"Zinc" },
	{ N_MSG_RING_MATERIAL_ZIRCONIUM,
		"Zirconium" },

#if	0
@@@
	{ N_MSG_RING_GEM_AMBER,
		"Amber" },
	{ N_MSG_RING_GEM_AGATE,
		"Agate" },
	{ N_MSG_RING_GEM_ALEXANDRITE,
		"Alexandrite" },
	{ N_MSG_RING_GEM_AMETHYST,
		"Amethyst" },
	{ N_MSG_RING_GEM_ANTLERITE,
		"Antlerite" },
	{ N_MSG_RING_GEM_AQUAMARINE,
		"Aquamarine" },
	{ N_MSG_RING_GEM_ARGENTITE,
		"Argentite" },
	{ N_MSG_RING_GEM_AZURITE,
		"Azurite" },
	{ N_MSG_RING_GEM_BERYL,
		"Beryl" },
	{ N_MSG_RING_GEM_BLOODSTONE,
		"Bloodstone" },
	{ N_MSG_RING_GEM_CALCITE,
		"Calcite" },
	{ N_MSG_RING_GEM_CARNELIAN,
		"Carnelian" },
	{ N_MSG_RING_GEM_CORAL,
		"Coral" },
	{ N_MSG_RING_GEM_CORUNDUM,
		"Corundum" },
	{ N_MSG_RING_GEM_CRYOLITE,
		"Cryolite" },
	{ N_MSG_RING_GEM_DIAMOND,
		"Diamond" },
	{ N_MSG_RING_GEM_DIORITE,
		"Diorite" },
	{ N_MSG_RING_GEM_EMERALD,
		"Emerald" },
	{ N_MSG_RING_GEM_FLINT,
		"Flint" },
	{ N_MSG_RING_GEM_FLUORITE,
		"Fluorite" },
	{ N_MSG_RING_GEM_GABBRO,
		"Gabbro" },
	{ N_MSG_RING_GEM_GARNET,
		"Garnet" },
	{ N_MSG_RING_GEM_GRANITE,
		"Granite" },
	{ N_MSG_RING_GEM_GYPSUM,
		"Gypsum" },
	{ N_MSG_RING_GEM_HEMATITE,
		"Hematite" },
	{ N_MSG_RING_GEM_JADE,
		"Jade" },
	{ N_MSG_RING_GEM_JASPER,
		"Jasper" },
	{ N_MSG_RING_GEM_KRYPTONITE,
		"Kryptonite" },
	{ N_MSG_RING_GEM_LAPIS_LAZULI,
		"Lapis_LAZULI" },
	{ N_MSG_RING_GEM_LIMESTONE,
		"Limestone" },
	{ N_MSG_RING_GEM_MALACHITE,
		"Malachite" },
	{ N_MSG_RING_GEM_MANGANITE,
		"Manganite" },
	{ N_MSG_RING_GEM_MARBLE,
		"Marble" },
	{ N_MSG_RING_GEM_MOONSTONE,
		"Moonstone" },
	{ N_MSG_RING_GEM_NEPTUNITE,
		"Neptunite" },
	{ N_MSG_RING_GEM_OBSIDIAN,
		"Obsidian" },
	{ N_MSG_RING_GEM_ONYX,
		"Onyx" },
	{ N_MSG_RING_GEM_OPAL,
		"Opal" },
	{ N_MSG_RING_GEM_PEARL,
		"Pearl" },
	{ N_MSG_RING_GEM_PYRITE,
		"Pyrite" },
	{ N_MSG_RING_GEM_QUARTZ,
		"Quartz" },
	{ N_MSG_RING_GEM_QUARTZITE,
		"Quartzite" },
	{ N_MSG_RING_GEM_RHODONITE,
		"Rhodonite" },
	{ N_MSG_RING_GEM_RHYOLITE,
		"Rhyolite" },
	{ N_MSG_RING_GEM_RUBY,
		"Ruby" },
	{ N_MSG_RING_GEM_SAPPHIRE,
		"Sapphire" },
	{ N_MSG_RING_GEM_SPHALERITE,
		"Sphalerite" },
	{ N_MSG_RING_GEM_STAUROLITE,
		"Staurolite" },
	{ N_MSG_RING_GEM_TIGER_EYE,
		"Tiger_EYE" },
	{ N_MSG_RING_GEM_TOPAZ,
		"Topaz" },
	{ N_MSG_RING_GEM_TURQUOISE,
		"Turquoise" },
	{ N_MSG_RING_GEM_ZIRCON,
		"Zircon" },
#endif

/* Light */

	{ N_MSG_LIGHT_TORCH,
		"Torch" },
	{ N_MSG_LIGHT_LANTERN,
		"Lantern" },
	{ N_MSG_LIGHT_LAMP,
		"Lamp" },

/* Spike */

	{ N_MSG_SPIKE,
		"Spike" },

/* Food */

	{ N_MSG_FOOD_PRESERVED,
		"Preserved Food" },
	{ N_MSG_FOOD_CHIPPED_BEEF,
		"Chipped Beef" },
	{ N_MSG_FOOD_CORNED_BEEF,
		"Corned Beef" },
	{ N_MSG_FOOD_BREAD,
		"Bread" },
	{ N_MSG_FOOD_BROWN_BREAD,
		"Brown Bread" },
	{ N_MSG_FOOD_TOAST,
		"Toast" },
	{ N_MSG_FOOD_PANCAKE,
		"Pancake" },
	{ N_MSG_FOOD_SALAD,
		"Salad" },
	{ N_MSG_FOOD_POTATO_SALAD,
		"Potato Salad" },
	{ N_MSG_FOOD_SCRAMBLED_EGGS,
		"Scrambled Eggs" },
	{ N_MSG_FOOD_FRIED_EGGS,
		"Fried Eggs" },
	{ N_MSG_FOOD_HARD_BOILED_EGGS,
		"Hard Boiled Eggs" },
	{ N_MSG_FOOD_SOFT_BOILED_EGGS,
		"Soft Boiled Eggs" },
	{ N_MSG_FOOD_BEEF_STEAK,
		"Beef Steak" },
	{ N_MSG_FOOD_PORK_SAUTE,
		"Pork Saute" },
	{ N_MSG_FOOD_FRIED_CHICKEN,
		"Fried Chicken" },
	{ N_MSG_FOOD_FRIED_FISH,
		"Fried Fish" },
	{ N_MSG_FOOD_FRIED_POTATO,
		"Fried Potato" },
	{ N_MSG_FOOD_STEWED_BEEF,
		"Stewed Beef" },
	{ N_MSG_FOOD_CONSOMME,
		"Consomme" },
	{ N_MSG_FOOD_POTAGE,
		"Potage" },
	{ N_MSG_FOOD_APPLE_PIE,
		"Apple Pie" },
	{ N_MSG_FOOD_APPLE,
		"Apple" },
	{ N_MSG_FOOD_GRAPE,
		"Grape" },
	{ N_MSG_FOOD_ORANGE,
		"Orange" },
	{ N_MSG_FOOD_PEAR,
		"Pear" },
	{ N_MSG_FOOD_GRAPEFRUIT,
		"Grapefruit" },
	{ N_MSG_FOOD_PLUM,
		"Plum" },
	{ N_MSG_FOOD_PEACH,
		"Peach" },
	{ N_MSG_FOOD_APRICOT,
		"Apricot" },
	{ N_MSG_FOOD_BLACK_BERRY,
		"Black Berry" },
	{ N_MSG_FOOD_CRAN_BERRY,
		"Cran Berry" },
	{ N_MSG_FOOD_RASP_BERRY,
		"Rasp Berry" },
	{ N_MSG_FOOD_STRAW_BERRY,
		"Straw Berry" },

/* Chest */

	{ N_MSG_CHEST,
		"Chest" },

/* Tobacco */

	{ N_MSG_TOBACCO_CIGARET,
		"Cigaret" },
	{ N_MSG_TOBACCO_CIGAR,
		"Cigar" },
	{ N_MSG_TOBACCO_CUT_TOBACCO,
		"Cut Tobacco" },
	{ N_MSG_TOBACCO_SNUFF_TOBACCO,
		"Snuff Tobacco" },
	{ N_MSG_TOBACCO_CHEWING_TOBACCO,
		"Chewing Tobacco" },
	{ N_MSG_TOBACCO_ABSTAIN_GUM,
		"Abstain Gum" },

/* CIGARET */
	{ N_MSG_TOBACCO_BRAND_HELLO,
		"HELLO" },
	{ N_MSG_TOBACCO_BRAND_SUN_SHINE,
		"SUN SHINE" },
	{ N_MSG_TOBACCO_BRAND_CHERRY_TREE,
		"CHERRY TREE" },
	{ N_MSG_TOBACCO_BRAND_GOLDEN_RAT,
		"GOLDEN RAT" },
	{ N_MSG_TOBACCO_BRAND_AIR_SHIT,
		"AIR SHIT" },
	{ N_MSG_TOBACCO_BRAND_HOP,
		"HOP" },
	{ N_MSG_TOBACCO_BRAND_PIECE,
		"PIECE" },
	{ N_MSG_TOBACCO_BRAND_HARPY,
		"HARPY" },
	{ N_MSG_TOBACCO_BRAND_HIGH_LIGHT,
		"HIGH LIGHT" },
	{ N_MSG_TOBACCO_BRAND_SHOOTING_STARS,
		"SHOOTING STARS" },
	{ N_MSG_TOBACCO_BRAND_WILD_NINE,
		"WILD NINE" },
	{ N_MSG_TOBACCO_BRAND_WILD_NINE_MENTHOL,
		"WILD NINE MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_LODGE,
		"LODGE" },
	{ N_MSG_TOBACCO_BRAND_LODGE_MENTHOL,
		"LODGE MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_CANCER,
		"CANCER" },
	{ N_MSG_TOBACCO_BRAND_CANCER_MENTHOL,
		"CANCER MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_FRONT_LINE,
		"FRONT LINE" },
	{ N_MSG_TOBACCO_BRAND_FRONT_LINE_MENTHOL,
		"FRONT LINE MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_MARCO_POLO,
		"MARCO POLO" },
	{ N_MSG_TOBACCO_BRAND_CAMELLIA,
		"CAMELLIA" },
	{ N_MSG_TOBACCO_BRAND_GOOD_LUCK,
		"GOOD LUCK" },
	{ N_MSG_TOBACCO_BRAND_BAD_GUY,
		"BAD GUY" },

/* CIGAR */
	{ N_MSG_TOBACCO_BRAND_ARCADIA,
		"ARCADIA" },
	{ N_MSG_TOBACCO_BRAND_GLORIA,
		"GLORIA" },
	{ N_MSG_TOBACCO_BRAND_VULCAN,
		"VULCAN" },
	{ N_MSG_TOBACCO_BRAND_PONY,
		"PONY" },
	{ N_MSG_TOBACCO_BRAND_KEITH,
		"KEITH" },
	{ N_MSG_TOBACCO_BRAND_LUMBERJACK,
		"LUMBERJACK" },
	{ N_MSG_TOBACCO_BRAND_CORONA,
		"CORONA" },
	{ N_MSG_TOBACCO_BRAND_HALF_CORONA,
		"HALF CORONA" },
	{ N_MSG_TOBACCO_BRAND_CRYSTAL,
		"CRYSTAL" },

/* CUT TOBACCO */
	{ N_MSG_TOBACCO_BRAND_FOREST_BRANDY,
		"FOREST BRANDY" },
	{ N_MSG_TOBACCO_BRAND_SILK_ROAD,
		"SILK ROAD" },
	{ N_MSG_TOBACCO_BRAND_PROMENADE,
		"PROMENADE" },
	{ N_MSG_TOBACCO_BRAND_BIG_HORN,
		"BIG HORN" },
	{ N_MSG_TOBACCO_BRAND_ROCKING_CHAIR,
		"ROCKING CHAIR" },
	{ N_MSG_TOBACCO_BRAND_VANILLA,
		"VANILLA" },
	{ N_MSG_TOBACCO_BRAND_WILD_MANGO,
		"WILD MANGO" },
	{ N_MSG_TOBACCO_BRAND_KENTUCKY_BIRD,
		"KENTUCKY BIRD" },
	{ N_MSG_TOBACCO_BRAND_ORIENT,
		"ORIENT" },
	{ N_MSG_TOBACCO_BRAND_FUJI,
		"FUJI" },

/* SNUFF TOBACCO */
	{ N_MSG_TOBACCO_BRAND_DOGGY_APRICOT,
		"DOGGY APRICOT" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_WHISKY,
		"DOGGY WHISKY" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_HONEY,
		"DOGGY HONEY" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_SPEARMINT,
		"DOGGY SPEARMINT" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_PEPPERMINT,
		"DOGGY PEPPERMINT" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_VANILLA,
		"DOGGY VANILLA" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_MENTHOL,
		"DOGGY MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_CITRUS,
		"DOGGY CITRUS" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_SHERRY,
		"DOGGY SHERRY" },

/* CHEWING TOBACCO */
	{ N_MSG_TOBACCO_BRAND_ROSE_PREMIUM,
		"ROSE PREMIUM" },
	{ N_MSG_TOBACCO_BRAND_ROSE_VANILLA,
		"ROSE VANILLA" },
	{ N_MSG_TOBACCO_BRAND_ROSE_MENTHOL,
		"ROSE MENTHOL" },

/* ABSTAIN GUM */
	{ N_MSG_TOBACCO_BRAND_NICOTIME,
		"NICOTIME" },

/* STUB */
	{ N_MSG_TOBACCO_STUB,
		"Stub" },

/* PIPE */
	{ N_MSG_PIPE_PIPE,
		"Pipe" },
	{ N_MSG_PIPE_KISEL,
		"Kisel" },
	{ N_MSG_PIPE_CIGARET_HOLDER,
		"Cigaret Holder" },
	{ N_MSG_PIPE_STUB,
		"Stub" },

	{ N_MSG_SMOKE_FAILURE,
		"You must equip pipe" },

/* Gold */

	{ N_MSG_COIN_GOLD,
		STR_GOLD },
	{ N_MSG_COIN_SILVER,
		"Silver coin" },
	{ N_MSG_COIN_COPPER,
		"Copper coin" },

/* misc */

	{ N_MSG_JUNK,
		"Junk" },

/**/

	{ N_MSG_TRGT,
		"Terget" },

/* mbr act */

	{ N_MSG_DOWN_DUN,
		"Down stairs" },
	{ N_MSG_UP_DUN,
		"Up stairs" },

	{ N_MSG_COLLECT_GOLD,
		"%s Collected %ld " STR_GOLD },
	{ N_MSG_DIVIDE_GOLD,
		"Party Divide %ld " STR_GOLD },
	{ N_MSG_NOT_FRIEND_GOLD,
		"%s " STR_GOLD "ΤȤǤä" },

	{ N_MSG_STOMACH_FULL,
		"%s ϤʢäѤˤʤä" },

	{ N_MSG_DOOR_OPEN,
		"%s ϥɥ򳫤" },
	{ N_MSG_DOOR_CLOSE,
		"%s ϥɥĤ" },
	{ N_MSG_DOOR_JAM,
		"%s ϥɥꤷ" },
	{ N_MSG_DOOR_DISARM,
		"%s ϥɥθ" STR_DISARM "" },
	{ N_MSG_DOOR_BREAK,
		"%s ϥɥ" },
	{ N_MSG_DOOR_SRCH,
		"%s ϥɥȯ" },

	{ N_MSG_SRCH_DOOR_SHOP,
		"%s ΥɥǤ" },
	{ N_MSG_SRCH_DOOR_OPEN,
		"ΥɥϳƤޤ" },
	{ N_MSG_SRCH_DOOR_CLOSE,
		"ΥɥĤƤޤ" },
	{ N_MSG_SRCH_DOOR_JAMMED,
		"ΥɥϸꤵƤޤ" },
	{ N_MSG_SRCH_DOOR_BROKEN,
		"ΥɥϲƤޤ" },

	{ N_MSG_TRAP_DISARM,
		"%s 櫤" STR_DISARM "" },
	{ N_MSG_TRAP_BREAK,
		"%s 櫤" },

	{ N_MSG_SRCH_TRAP,
		" %s 櫤Ǥ" },

	{ N_MSG_ITEM_PICK_UP,
		"%s  %s 򽦤ä" },
	{ N_MSG_ITEM_OPEN,
		"%s  %s 򳫤" },
	{ N_MSG_ITEM_DISARM,
		"%s  %s Υ" STR_DISARM "" },
	{ N_MSG_ITEM_BREAK,
		"%s  %s " },
	{ N_MSG_SRCH_ITEM,
		" %s " },

	{ N_MSG_READY_THROW_CHEST,
		"%s ˲äƤ" },

	{ N_MSG_DONT_EXHIBIT_ABL_EQUIP,
		"%s Τ %s ǽϤȯǤʤ" },

	{ N_MSG_ERR_HP_SHORT,
		"%s  HP  %ld ­ʤ" },
	{ N_MSG_ERR_MP_SHORT,
		"%s  MP  %ld ­ʤ" },

/* FX */

	{ N_MSG_FX_QUAFF_POTION,
		"%s  %s " },
	{ N_MSG_FX_READ_SCROLL,
		"%s  %s ɤ" },
	{ N_MSG_FX_ZAP_STICK,
		"%s  %s ä" },

	{ N_MSG_FX_STONE,
		"%s ФˤʤäƤޤä" },
	{ N_MSG_FX_PARALYZE,
		"%s 㤷Ƥޤä" },
	{ N_MSG_FX_POISON,
		"%s Ǥ줿" },
	{ N_MSG_FX_CONFUSION,
		"%s Ϻ𤷤Ƥޤä" },
	{ N_MSG_FX_BLIND,
		"%s ܤʤʤäƤޤä" },
	{ N_MSG_FX_SLEEP,
		"%s ̲äƤޤä" },
	{ N_MSG_FX_SILENCE,
		"%s ʤʤä" },
	{ N_MSG_FX_FEAR,
		"%s ϶ݤ˼Ĥ줿" },
	{ N_MSG_FX_HALLUCINATION,
		"%s ϸФ˽줿" },
	{ N_MSG_FX_CHARM,
		"%s ̥λ줿" },
	{ N_MSG_FX_FLY,
		"%s Τ⤫Ӿ夬ä" },
	{ N_MSG_FX_VANISH,
		"%s ΤƩˤʤä" },
	{ N_MSG_FX_DRUNK,
		"%s ϿäѤä" },

	{ N_MSG_FX_RESI_PHYS,
		"%s ϶ˤȤ줿" },
	{ N_MSG_FX_RESI_WIND,
		"%s ϿϤ褤򴶤" },
	{ N_MSG_FX_RESI_HEAT,
		"%s äʤä" },
	{ N_MSG_FX_RESI_COLD,
		"%s Ȥʤä" },
	{ N_MSG_FX_RESI_ELEC,
		"%s ŵä" },
	{ N_MSG_FX_RESI_ACID,
		"%s ȩ٥٤ˤʤä" },
	{ N_MSG_FX_RESI_POIS,
		"%s ϵɤʤä" },

	{ N_MSG_FX_SHARPNESS,
		"%s Τפɤư" },
	{ N_MSG_FX_DULLNESS,
		"%s Τפɤưʤ" },
	{ N_MSG_FX_STRENGTH,
		"%s Ϥߤʤä" },
	{ N_MSG_FX_WEAKNESS,
		"%s Ϥȴ" },
	{ N_MSG_FX_QUICKNESS,
		"%s Τڤ" },
	{ N_MSG_FX_SLOWNESS,
		"%s ΤŤ" },
	{ N_MSG_FX_WISE,
		"%s ϸʤä" },
	{ N_MSG_FX_FOOLISH,
		"%s ϶򤫤ˤʤäƤޤä" },
	{ N_MSG_FX_BRAINY,
		"%s Ƭɤʤä" },
	{ N_MSG_FX_BRAINLESS,
		"%s ƬʤäƤޤä" },
	{ N_MSG_FX_ATTRACTIVE,
		"%s ʤä" },
	{ N_MSG_FX_UNATTRACTIVE,
		"%s ϽʤäƤޤä" },

	{ N_MSG_FX_WATER,
		"%s Ϲ뤪ä" },
	{ N_MSG_FX_OIL,
		"" },
	{ N_MSG_FX_CURE_LEV,
		"%s ΤפФ" },
	{ N_MSG_FX_CURE_HP_LIGHT,
		"%s Ͻä" },
	{ N_MSG_FX_CURE_HP_MODERATE,
		"%s Ͻּä" },
	{ N_MSG_FX_CURE_HP_SERIOUS,
		"%s Ͻʤ꼣ä" },
	{ N_MSG_FX_CURE_HP_MAX,
		"%s Ͻ˼ä" },
	{ N_MSG_FX_CURE_POISON,
		"%s Ǥޤä" },
	{ N_MSG_FX_CURE_STATUS,
		"%s ϵʬɤʤä" },
	{ N_MSG_FX_CREATE_FOOD,
		"%s  %s " },
	{ N_MSG_FX_DETECT_MNSTR,
		"%s ϥ󥹥εۤ򴶤" },
	{ N_MSG_FX_DETECT_ITEM,
		"%s ϥƥΰ֤򴶤" },
	{ N_MSG_FX_POW_UP_HP,
		"%s ϥդˤʤä" },
	{ N_MSG_FX_SPEED_UP,
		"%s ư®ʤä" },
	{ N_MSG_FX_SPEED_DOWN,
		"%s ư٤ʤä" },
	{ N_MSG_FX_SENSE_INVISIBLE,
		"%s ܤɤʤäͤ" },
	{ N_MSG_FX_TELEPORT_PARTY,
		"ηʿޤѤä" },
	{ N_MSG_FX_TELEPORT,
		"%s μηʿޤѤä" },
	{ N_MSG_FX_RECALL,
		"㡼.." },
	{ N_MSG_FX_TOBACCO_ABSTAIN,
		"%s ϥХۤʤä" },
	{ N_MSG_FX_SMOKE_TOBACCO,
		"򹯤Τۤ᤮դޤ礦" },
	{ N_MSG_FX_SMOKE_END,
		"%s ϥХۤä" },
	{ N_MSG_FX_BREAK_PIPE,
		"%s  %s ϻȤä" },

	{ N_MSG_FX_IDENTIFY_ITEM,
		"ɤΥƥ̤ޤ? ([ESC]:󥻥)" },
	{ N_MSG_FX_RECALL_ASK,
		"عԤΤ?" },

	{ N_MSG_FX_SLEEP_SUCCESS,
		"%s μϤΥ󥹥̲äƤޤä" },
	{ N_MSG_FX_SLEEP_FAILURE,
		"%s »򤷤ͤʵˤʤä" },
	{ N_MSG_FX_POW_UP_WPN_HIT_SUCCESS,
		"%s 郎פʤä" },
	{ N_MSG_FX_POW_UP_WPN_HIT_FAILURE,
		"%s ξ꤬Ĥä" },
	{ N_MSG_FX_POW_UP_WPN_CRTCL_SUCCESS,
		"%s Υƥ뤬Ф䤹ʤä" },
	{ N_MSG_FX_POW_UP_WPN_CRTCL_FAILURE,
		"%s ξ꤬Ĥä" },
	{ N_MSG_FX_POW_UP_WPN_DAM_SUCCESS,
		"%s Υ᡼礭ʤä" },
	{ N_MSG_FX_POW_UP_WPN_DAM_FAILURE,
		"%s ξ꤬Ĥä" },
	{ N_MSG_FX_REMOVE_CURSE_SUCCESS,
		"%s μ򤱤" },
	{ N_MSG_FX_REMOVE_CURSE_FAILURE,
		"%s äѤϤʤ" },

/* FX CLR */

	{ N_MSG_CLR_FX_STONE,
		"%s ȤΤä" },
	{ N_MSG_CLR_FX_PARALYZE,
		"%s ϤӤ줬ä" },
	{ N_MSG_CLR_FX_POISON,
		"%s Ǥޤä" },
	{ N_MSG_CLR_FX_CONFUSION,
		"%s Ϻ𤬼ޤä" },
	{ N_MSG_CLR_FX_BLIND,
		"%s ܤͤˤʤä" },
	{ N_MSG_CLR_FX_SLEEP,
		"%s ܤФ᤿" },
	{ N_MSG_CLR_FX_SILENCE,
		"%s ͤˤʤä" },
	{ N_MSG_CLR_FX_FEAR,
		"%s ϶̵ʤä" },
	{ N_MSG_CLR_FX_HALLUCINATION,
		"%s ϸФޤä" },
	{ N_MSG_CLR_FX_CHARM,
		"%s ϼ" },
	{ N_MSG_CLR_FX_FLY,
		"%s Ϥ" },
	{ N_MSG_CLR_FX_DRUNK,
		"%s Ͽ줤᤿" },
	{ N_MSG_CLR_FX_VANISH,
		"%s Τͤˤʤä" },

	{ N_MSG_CLR_FX_RESI_KNOC,
		"%s ᡹ˤ" },
	{ N_MSG_CLR_FX_RESI_SLAS,
		"%s ᡹ˤ" },
	{ N_MSG_CLR_FX_RESI_STIN,
		"%s ᡹ˤ" },
	{ N_MSG_CLR_FX_RESI_HEAT,
		"%s Ͼ뤤" },
	{ N_MSG_CLR_FX_RESI_COLD,
		"%s ϴ" },
	{ N_MSG_CLR_FX_RESI_WIND,
		"%s ©줷ʤä" },
	{ N_MSG_CLR_FX_RESI_ACID,
		"%s Τҥҥꤹ" },
	{ N_MSG_CLR_FX_RESI_ELEC,
		"%s ŵѥѥ" },
	{ N_MSG_CLR_FX_RESI_POIS,
		"%s ϵʤä" },

	{ N_MSG_CLR_FX_SHARPNESS,
		"%s Τפɤưʤ" },
	{ N_MSG_CLR_FX_DULLNESS,
		"%s Τפɤư" },
	{ N_MSG_CLR_FX_STRENGTH,
		"%s Ϥȴ" },
	{ N_MSG_CLR_FX_WEAKNESS,
		"%s Ϥߤʤä" },
	{ N_MSG_CLR_FX_QUICKNESS,
		"%s ΤŤ" },
	{ N_MSG_CLR_FX_SLOWNESS,
		"%s Τڤ" },
	{ N_MSG_CLR_FX_WISE,
		"%s ϶򤫤ˤʤäƤޤä" },
	{ N_MSG_CLR_FX_FOOLISH,
		"%s ϸʤä" },
	{ N_MSG_CLR_FX_BRAINY,
		"%s ƬʤäƤޤä" },
	{ N_MSG_CLR_FX_BRAINLESS,
		"%s Ƭɤʤä" },
	{ N_MSG_CLR_FX_ATTRACTIVE,
		"%s ϽʤäƤޤä" },
	{ N_MSG_CLR_FX_UNATTRACTIVE,
		"%s ʤä" },

	{ N_MSG_CLR_FX_SENSE_INVISIBLE,
		"%s ܤʤäͤ" },
	{ N_MSG_CLR_FX_POW_UP_HP,
		"%s ϤҼˤʤä" },
	{ N_MSG_CLR_FX_SPEED,
		"%s ϸ®ä" },

/* ̣ʪ */

	{ N_MSG_FX_DRINK_A00,
		"̣ %s " },
	{ N_MSG_FX_DRINK_A01,
		" %s ϡΤɤɤ" },
	{ N_MSG_FX_DRINK_A02,
		" %s Ͼʤʹ꤬" },
	{ N_MSG_FX_DRINK_A03,
		" %s Ͼʤ̣" },
	{ N_MSG_FX_DRINK_A04,
		" %s ϸ̣ɤ" },
	{ N_MSG_FX_DRINK_A05,
		"Ϥޤ䤫 %s " },

/* ޤʪ */

	{ N_MSG_FX_DRINK_B00,
		"Ϥޤ %s " },

/* ̣ʪ */

	{ N_MSG_FX_EAT_FOOD_A00,
		"̣ %s " },
	{ N_MSG_FX_EAT_FOOD_A01,
		"ޤäȤ %s " },
	{ N_MSG_FX_EAT_FOOD_A02,
		" %s " },
	{ N_MSG_FX_EAT_FOOD_A03,
		"äȤ %s " },
	{ N_MSG_FX_EAT_FOOD_A04,
		"äƤȤ %s " },
	{ N_MSG_FX_EAT_FOOD_A05,
		"Ĥʤ̣ %s " },
	{ N_MSG_FX_EAT_FOOD_A06,
		"Ͽ̣襤Τ %s " },
	{ N_MSG_FX_EAT_FOOD_A07,
		"ϵˤ %s " },
	{ N_MSG_FX_EAT_FOOD_A08,
		"ϻ %s " },

/* ޤʪ */

	{ N_MSG_FX_EAT_FOOD_B00,
		"Ϥޤ %s " },
	{ N_MSG_FX_EAT_FOOD_B01,
		" %s ϡḤ̂" },
	{ N_MSG_FX_EAT_FOOD_B02,
		"ʤ %s ! ĹƤ!" },

/* mnstr */

	{ N_MSG_MNSTR_UNKNOWN,
		"Υ󥹥" },
	{ N_MSG_MNSTR_GIANT_BAT,
		"㥤ȡХå" },
	{ N_MSG_MNSTR_GIANT_RAT,
		"㥤ȡå" },
	{ N_MSG_MNSTR_MIMIC,
		"ߥߥå" },
#if	0
	{ N_MSG_MNSTR_ANCIENT_BLACK_DRAGON,
		"󥷥ȡ֥åɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_BLUE_DRAGON,
		"󥷥ȡ֥롼ɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_RED_DRAGON,
		"󥷥ȡåɡɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_WHITE_DRAGON,
		"󥷥ȡۥ磻ȡɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_YELLOW_DRAGON,
		"󥷥ȡɥ饴" },
	{ N_MSG_MNSTR_MINOR_BLACK_DRAGON,
		"ޥʡ֥åɥ饴" },
	{ N_MSG_MNSTR_MINOR_BLUE_DRAGON,
		"ޥʡ֥롼ɥ饴" },
	{ N_MSG_MNSTR_MINOR_RED_DRAGON,
		"ޥʡåɡɥ饴" },
	{ N_MSG_MNSTR_MINOR_WHITE_DRAGON,
		"ޥʡۥ磻ȡɥ饴" },
	{ N_MSG_MNSTR_MINOR_YELLOW_DRAGON,
		"ޥʡɥ饴" },
	{ N_MSG_MNSTR_BEHEMOTH,
		"ӥҥ⥹" },
	{ N_MSG_MNSTR_SALAMANDER,
		"ޥ" },
	{ N_MSG_MNSTR_BANSHEE,
		"Х󥷡" },
	{ N_MSG_MNSTR_DJINNI,
		"" },
	{ N_MSG_MNSTR_EFREET,
		"ե꡼" },
	{ N_MSG_MNSTR_GNOME,
		"Ρ" },
	{ N_MSG_MNSTR_BROWNIE,
		"֥饦ˡ" },
	{ N_MSG_MNSTR_PHOENIX,
		"ե˥å" },
	{ N_MSG_MNSTR_SYLPH,
		"" },
	{ N_MSG_MNSTR_UNDINE,
		"ǥ" },
	{ N_MSG_MNSTR_WILL_O_WISP,
		"롦" },
	{ N_MSG_MNSTR_COATL,
		"ȥ" },
	{ N_MSG_MNSTR_NAGA,
		"ʡ" },
	{ N_MSG_MNSTR_LYCANTHROPE,
		"饤󥹥" },
	{ N_MSG_MNSTR_MINOTAUR,
		"ߥΥ" },
	{ N_MSG_MNSTR_SATYR,
		"ƥ" },
	{ N_MSG_MNSTR_ANDRO_SCORPION,
		"ɥԥ" },
	{ N_MSG_MNSTR_BIRD_MAN,
		"Сɥޥ" },
	{ N_MSG_MNSTR_CENTAUR,
		"󥿥" },
	{ N_MSG_MNSTR_MEDUSA,
		"ǥ塼" },
	{ N_MSG_MNSTR_GILLMAN,
		"ޥ" },
	{ N_MSG_MNSTR_HARPY,
		"ϡԡ" },
	{ N_MSG_MNSTR_LAMIA,
		"ߥ" },
	{ N_MSG_MNSTR_MERMAN,
		"ޡޥ" },
	{ N_MSG_MNSTR_GNOLL,
		"Ρ" },
	{ N_MSG_MNSTR_SIREN,
		"졼" },
	{ N_MSG_MNSTR_SCYLLA,
		"" },
	{ N_MSG_MNSTR_LIZARDMAN,
		"ꥶɥޥ" },
	{ N_MSG_MNSTR_CAVEMAN,
		"ޥ" },
	{ N_MSG_MNSTR_GIANT,
		"㥤" },
	{ N_MSG_MNSTR_HUMBABA,
		"եХ" },
	{ N_MSG_MNSTR_TROLL,
		"ȥ" },
	{ N_MSG_MNSTR_YETI,
		"ƥ" },
	{ N_MSG_MNSTR_BEAR,
		"٥" },
	{ N_MSG_MNSTR_ROC,
		"å" },
	{ N_MSG_MNSTR_BAT,
		"Хå" },
	{ N_MSG_MNSTR_GREAT_CAT,
		"졼ȡå" },
	{ N_MSG_MNSTR_DOG,
		"ɥå" },
	{ N_MSG_MNSTR_HORSE,
		"ۡ" },
	{ N_MSG_MNSTR_WOLF,
		"" },
	{ N_MSG_MNSTR_BEHOLDER,
		"ӥۥ" },
	{ N_MSG_MNSTR_CERBERUS,
		"٥" },
	{ N_MSG_MNSTR_GRIFFON,
		"ե" },
	{ N_MSG_MNSTR_HYDRA,
		"ҥɥ" },
	{ N_MSG_MNSTR_HIPPOGRIFF,
		"ҥݥ" },
	{ N_MSG_MNSTR_BASILISK,
		"Хꥹ" },
	{ N_MSG_MNSTR_CHIMERA,
		"ޥ" },
	{ N_MSG_MNSTR_GORGON,
		"르" },
	{ N_MSG_MNSTR_HELLHOUND,
		"إ롦ϥ" },
	{ N_MSG_MNSTR_MANTICORE,
		"ޥƥ" },
	{ N_MSG_MNSTR_COCKATRICE,
		"ȥꥹ" },
	{ N_MSG_MNSTR_PEGASUS,
		"ڥ" },
	{ N_MSG_MNSTR_RUST_MONSTER,
		"饹ȡ󥹥" },
	{ N_MSG_MNSTR_UNICORN,
		"˥" },
	{ N_MSG_MNSTR_WYVERN,
		"磻С" },
	{ N_MSG_MNSTR_DOPPELGANGER,
		"ɥåڥ륲󥬡" },
	{ N_MSG_MNSTR_SUCCUBUS,
		"Х" },
	{ N_MSG_MNSTR_DURAHAN,
		"ǥϥ" },
	{ N_MSG_MNSTR_GREMLIN,
		"" },
	{ N_MSG_MNSTR_IMP,
		"" },
	{ N_MSG_MNSTR_MIND_FLAYER,
		"ޥɡե쥤䡼" },
	{ N_MSG_MNSTR_DWARF,
		"ɥ" },
	{ N_MSG_MNSTR_DRYAD,
		"ɥ饤" },
	{ N_MSG_MNSTR_ELF,
		"" },
	{ N_MSG_MNSTR_FAIRY,
		"ե꡼" },
	{ N_MSG_MNSTR_HALFLING,
		"ϡե" },
	{ N_MSG_MNSTR_LEPRECHAUN,
		"ץ饳" },
	{ N_MSG_MNSTR_PIXY,
		"ԥ" },
	{ N_MSG_MNSTR_GHOST,
		"" },
	{ N_MSG_MNSTR_POLTERGEIST,
		"ݥ륿" },
	{ N_MSG_MNSTR_SPIRIT,
		"ԥå" },
	{ N_MSG_MNSTR_WRAITH,
		"쥤" },
	{ N_MSG_MNSTR_OGRE,
		"" },
	{ N_MSG_MNSTR_GOBLIN,
		"֥" },
	{ N_MSG_MNSTR_HOBGOBLIN,
		"ۥ֥֥" },
	{ N_MSG_MNSTR_KOBOLD,
		"ܥ" },
	{ N_MSG_MNSTR_ORK,
		"" },
	{ N_MSG_MNSTR_GIANT_SPIDER,
		"㥤ȡѥ" },
	{ N_MSG_MNSTR_GIANT_ANT,
		"㥤ȡ" },
	{ N_MSG_MNSTR_GIANT_BEETLE,
		"㥤ȡӡȥ" },
	{ N_MSG_MNSTR_GIANT_CENTIPEDE,
		"㥤ȡƥԡ" },
	{ N_MSG_MNSTR_GIANT_SCORPION,
		"㥤ȡԥ" },
	{ N_MSG_MNSTR_WORM,
		"" },
	{ N_MSG_MNSTR_GOLEM,
		"" },
	{ N_MSG_MNSTR_GAS_CLOUD,
		"饦" },
	{ N_MSG_MNSTR_GARGOYLE,
		"" },
	{ N_MSG_MNSTR_HOMUNCULUS,
		"ۥ󥯥륹" },
	{ N_MSG_MNSTR_INVISIBLE_STALKER,
		"֥롦ȡ" },
	{ N_MSG_MNSTR_JACK_O_LANTERN,
		"å󥿥" },
	{ N_MSG_MNSTR_SLIME,
		"饤" },
	{ N_MSG_MNSTR_HAG,
		"ϥ" },
	{ N_MSG_MNSTR_DINOSAUR,
		"ʥ" },
	{ N_MSG_MNSTR_GIANT_LIZARD,
		"㥤ȡꥶ" },
	{ N_MSG_MNSTR_SNAKE,
		"͡" },
	{ N_MSG_MNSTR_MANDRAKE,
		"ޥɥ쥤" },
	{ N_MSG_MNSTR_PLANT_MONSTER,
		"ץȡ󥹥" },
	{ N_MSG_MNSTR_SPORE,
		"ݥ" },
	{ N_MSG_MNSTR_TREANT,
		"ȥ" },
	{ N_MSG_MNSTR_KRAKEN,
		"顼" },
	{ N_MSG_MNSTR_SEA_SERPENT,
		"ڥ" },
	{ N_MSG_MNSTR_GHOUL,
		"" },
	{ N_MSG_MNSTR_MUMMY,
		"ޥߡ" },
	{ N_MSG_MNSTR_SKELETON,
		"ȥ" },
	{ N_MSG_MNSTR_VAMPIRE,
		"ѥ" },
	{ N_MSG_MNSTR_WIGHT,
		"磻" },
	{ N_MSG_MNSTR_ZOMBIE,
		"" },
#endif

	{ N_MSG_MIMIC_FIND_MBR,
		"Ԥơ %s " },

/* trap */

	{ N_MSG_TRAP_SLEEP,
		"̲" },
	{ N_MSG_TRAP_ARW,
		"" },
	{ N_MSG_TRAP_POISON_DARTS,
		"ǥĤ" },
	{ N_MSG_TRAP_TELEPORT_PARTY,
		"ѡƥְִư" },
	{ N_MSG_TRAP_TELEPORT,
		"ְִư" },

	{ N_MSG_TRAPPED,
		"%s  %s ˤä" },
	{ N_MSG_NOT_TRAPPED,
		"%s 櫤ưʤä" },

/* spell begin */

	{ N_MSG_MAG,
		STR_MAG },
	{ N_MSG_SOR,
		STR_SOR },
	{ N_MSG_ENC,
		STR_ENC },
	{ N_MSG_SUM,
		STR_SUM },

	{ N_MSG_PRI,
		STR_PRI },
	{ N_MSG_SHA,
		STR_SHA },
	{ N_MSG_BAR,
		STR_BAR },
	{ N_MSG_NIN,
		STR_NIN },

	{ N_MSG_MAG_MISC,
		STR_MAG " - " },
	{ N_MSG_MAG_DETECT,
		STR_MAG " - õ" },
	{ N_MSG_MAG_CHANGE_STAT,
		STR_MAG " - ƥѲ" },
	{ N_MSG_SOR_ATTACK,
		STR_SOR " - " },
	{ N_MSG_SOR_DEFENSE,
		STR_SOR " - ɸ" },
	{ N_MSG_SOR_WEAKEN_STAT,
		STR_SOR " - ơ۾" },
	{ N_MSG_ENC_STRENGTHEN_ABILITY,
		STR_ENC " - ӥƥ" },
	{ N_MSG_ENC_STRENGTHEN_MISC,
		STR_ENC " - " },
	{ N_MSG_ENC_WEAKEN_ABILITY,
		STR_ENC " - ӥƥ" },
	{ N_MSG_ENC_WEAKEN_MISC,
		STR_ENC " - " },
	{ N_MSG_SUM_SUMMON,
		STR_SUM " - " },
	{ N_MSG_PRI_HOLY,
		STR_PRI " - " },
	{ N_MSG_PRI_RESIST,
		STR_PRI " - " },
	{ N_MSG_PRI_CURE,
		STR_PRI " - " },
	{ N_MSG_PRI_CURE_STAT,
		STR_PRI " - ֲ" },
	{ N_MSG_NIN_DISASTER,
		STR_NIN " - ŷϰ" },
	{ N_MSG_NIN_MISC,
		STR_NIN " - " },

	{ N_MSG_ERR_SPELL,
		"%s ϼʸФƤʤ" },
	{ N_MSG_SPELL_NO_LEARN,
		"̵" },

/* [ˡ] */

/*  */

	{ N_MSG_SPELL_LIGHT,
		"" },
	{ N_MSG_SPELL_DARKNESS,
		"Ű" },
	{ N_MSG_SPELL_KNOCK,
		"" },
	{ N_MSG_SPELL_LOCK,
		"ܾ" },
	{ N_MSG_SPELL_DISARM_TRAP,
		"櫲" },
	{ N_MSG_SPELL_DISPEL_MAGIC,
		"ˡ" },
	{ N_MSG_SPELL_TELEPORT_PARTY,
		"ѡƥְִư" },
	{ N_MSG_SPELL_TELEPORT,
		"ְִư" },
	{ N_MSG_SPELL_RECALL,
		"" },
	{ N_MSG_SPELL_MIRROR_IMAGE,
		"" },
	{ N_MSG_SPELL_ANIMATE_OBJECTS,
		"ʪ" },
	{ N_MSG_SPELL_SHELTER,
		"륿" },
	{ N_MSG_SPELL_CREATE_FOOD,
		"" },
	{ N_MSG_SPELL_CREATE_UNDEAD,
		"ǥå¤" },

/* õΡ */

	{ N_MSG_SPELL_IDENTIFY_ITEM,
		"" },
	{ N_MSG_SPELL_SEARCHING,
		"õ" },
	{ N_MSG_SPELL_ANALYZE_DWEOMER,
		"ʬ" },
	{ N_MSG_SPELL_DETECT_DOORS,
		"õ" },
	{ N_MSG_SPELL_DETECT_ITEM,
		"ƥõ" },
	{ N_MSG_SPELL_DETECT_MAGIC,
		"ˡ" },
	{ N_MSG_SPELL_DETECT_MONSTER,
		"󥹥" },
	{ N_MSG_SPELL_DETECT_TRAPS,
		"õ" },
	{ N_MSG_SPELL_SENSE_INVISIBLE,
		"ԲĻ봶" },

/* Ѳ_ƥ */

	{ N_MSG_SPELL_FLY,
		"ͷ" },
	{ N_MSG_SPELL_FEATHER_FALL,
		"Φ" },
	{ N_MSG_SPELL_VANISH,
		"ԲĻ" },
	{ N_MSG_SPELL_DARKVISION,
		"Ż" },
	{ N_MSG_SPELL_PASSWALL,
		"ȴ" },

/* Ѳ_üե饰 */

	{ N_MSG_SPELL_POLYMORPH_OTHER,
		"¾ѿ" },
	{ N_MSG_SPELL_POLYMORPH_SELF,
		"ѿ" },
	{ N_MSG_SPELL_STEALTH,
		"̩" },

/* [Ʈˡ] */

/*  */

	{ N_MSG_SPELL_MAGIC_MISSILE,
		"ˡΥߥ" },
	{ N_MSG_SPELL_FIRE_BALL,
		"Фε" },
	{ N_MSG_SPELL_ICE_BLIZZARD,
		"ɹο" },
	{ N_MSG_SPELL_MIND_STORM,
		"" },
	{ N_MSG_SPELL_ACID_RAIN,
		"α" },
	{ N_MSG_SPELL_LIGHTNING_BOLT,
		"ŷ" },
	{ N_MSG_SPELL_POISON_CLOUD,
		"Ǥα" },
	{ N_MSG_SPELL_DEATH_SPELL,
		"μ" },

/* ɸ */

	{ N_MSG_SPELL_MAGE_ARMOR,
		"ˡγ" },
	{ N_MSG_SPELL_MAGIC_SHIELD,
		"ˡν" },
	{ N_MSG_SPELL_STONESKIN,
		"Ф" },
	{ N_MSG_SPELL_IRON_BODY,
		"Ŵ" },
	{ N_MSG_SPELL_SPELL_RESISTANCE,
		"ʸ" },
	{ N_MSG_SPELL_COUNTER_MAGIC,
		"ʸȿ" },

/* _ƥ */

	{ N_MSG_SPELL_STONE,
		"в" },
	{ N_MSG_SPELL_PARALYZE,
		"" },
	{ N_MSG_SPELL_POISON,
		"" },
	{ N_MSG_SPELL_CONFUSION,
		"" },
	{ N_MSG_SPELL_BLINDNESS,
		"" },
	{ N_MSG_SPELL_SLEEP,
		"̲" },
	{ N_MSG_SPELL_SILENCE,
		"ż" },
	{ N_MSG_SPELL_FEAR,
		"" },
	{ N_MSG_SPELL_HALLUCINATION,
		"" },
	{ N_MSG_SPELL_CHARM,
		"̥λ" },

/* [ˡ] */

/* _٥ */

	{ N_MSG_SPELL_SHARPNESS,
		"" },
	{ N_MSG_SPELL_STRENGTH,
		"" },
	{ N_MSG_SPELL_QUICKNESS,
		"Ҿ" },
	{ N_MSG_SPELL_WISE,
		"Ƚ" },
	{ N_MSG_SPELL_BRAINY,
		"" },
	{ N_MSG_SPELL_ATTRACTIVE,
		"̥" },

/* _ */

	{ N_MSG_SPELL_POWER_UP_HP,
		"" },

/* _üե饰 */

	{ N_MSG_SPELL_HASTE,
		"®" },

/* _٥ */

	{ N_MSG_SPELL_DULLNESS,
		"ٸ" },
	{ N_MSG_SPELL_WEAKNESS,
		"ٸ" },
	{ N_MSG_SPELL_SLOWNESS,
		"Ҿٸ" },
	{ N_MSG_SPELL_FOOLISH,
		"Ƚϸ" },
	{ N_MSG_SPELL_BRAINLESS,
		"ϸ" },
	{ N_MSG_SPELL_UNATTRACTIVE,
		"̥ϸ" },

/* _и */

	{ N_MSG_SPELL_ENERGY_DRAIN,
		"̿ϵۼ" },

/* _üե饰 */

	{ N_MSG_SPELL_SLOW,
		"®" },
	{ N_MSG_SPELL_HUNGER,
		"" },
	{ N_MSG_SPELL_CANCELLATION,
		"üǽ" },

/* [ˡ] */

/* */
	{ N_MSG_SPELL_SUMMON_MONSTER,
		"ʪ" },
	{ N_MSG_SPELL_DISMISSAL,
		"" },

/* [] */

/* Ͳ */

	{ N_MSG_SPELL_CURE_HP_LIGHT,
		"Ͼ" },
	{ N_MSG_SPELL_CURE_HP_MODERATE,
		"" },
	{ N_MSG_SPELL_CURE_HP_SERIOUS,
		"" },
	{ N_MSG_SPELL_CURE_HP_MAX,
		"" },
	{ N_MSG_SPELL_CURE_MP,
		"ϲ" },
	{ N_MSG_SPELL_TRANSFER_MP,
		"ž" },
	{ N_MSG_SPELL_REGENERATION,
		"" },
	{ N_MSG_SPELL_RESTORE_EXPERIENCE,
		"иͲ" },
	{ N_MSG_SPELL_RESURRECTION,
		"" },
	{ N_MSG_SPELL_HEAL,
		"" },

/* ֲ */

	{ N_MSG_SPELL_CURE_STATUS,
		"ֲ" },

	{ N_MSG_SPELL_CURE_STONE,
		"в" },
	{ N_MSG_SPELL_CURE_PARALYZE,
		"" },
	{ N_MSG_SPELL_CURE_BLINDNESS,
		"ܲ" },
	{ N_MSG_SPELL_CURE_POISON,
		"ǲ" },
	{ N_MSG_SPELL_CURE_CONFUSION,
		"" },
	{ N_MSG_SPELL_CURE_SILENCE,
		"ż" },
	{ N_MSG_SPELL_CURE_SLEEP,
		"̲" },
	{ N_MSG_SPELL_CURE_FEAR,
		"ݲ" },
	{ N_MSG_SPELL_CURE_HALLUCINATION,
		"в" },
	{ N_MSG_SPELL_CURE_CHARM,
		"̥λ" },

	{ N_MSG_SPELL_REMOVE_CURSE,
		"" },

/*  */

	{ N_MSG_SPELL_PROTECTION,
		"ɸ" },
	{ N_MSG_SPELL_RESIST_ACID,
		"ڻ" },
	{ N_MSG_SPELL_RESIST_COLD,
		"" },
	{ N_MSG_SPELL_RESIST_ELECTRICITY,
		"" },
	{ N_MSG_SPELL_RESIST_HEAT,
		"Ǯ" },
	{ N_MSG_SPELL_RESIST_PHYSICAL,
		"ʪ" },
	{ N_MSG_SPELL_RESIST_POISON,
		"" },
	{ N_MSG_SPELL_RESIST_WIND,
		"" },

/*  */

	{ N_MSG_SPELL_BLESS,
		"ʡ" },
	{ N_MSG_SPELL_DISPEL_UNDEAD,
		"ǥå໶" },
	{ N_MSG_SPELL_SANCTUARY,
		"" },
	{ N_MSG_SPELL_WISH,
		"˾" },

/* [Ǧ] */

/* ŷϰ */

#if	0
@@@
	{ N_MSG_SPELL_,
		"ۤν()" },
#endif
	{ N_MSG_SPELL_CONFLAGRATION,
		"ۤν(к)" },
	{ N_MSG_SPELL_EARTHQUAKE,
		"ۤν(Ͽ)" },
	{ N_MSG_SPELL_THUNDERCLOUD,
		"ۤν()" },
	{ N_MSG_SPELL_INUNDATION,
		"ۤν()" },

#if	0
@@@
/*  */

	{ N_MSG_SPELL_,
		"ۤν(Ф)" },
	{ N_MSG_SPELL_,
		"ۤν(оä)" },
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν(Ϥ)" },
#endif

/*  */

	{ N_MSG_SPELL_SUBSTITUTE,
		"ۤν()" },
	{ N_MSG_SPELL_BURNING_HANDS,
		"ۤν()" },
#if	0
@@@
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν()" },
#endif

/* ANC */

	{ N_MSG_SPELL_NOTHING,
		"̵" },

/* spell end */

/* color begin */

	{ N_MSG_ATTR_NORMAL,
		"̾ο" },
	{ N_MSG_ATTR_ERR,
		"顼ο" },
	{ N_MSG_ATTR_MENU_DIS,
		"̵ʥ˥塼ܤο" },
	{ N_MSG_ATTR_MENU_SEL,
		"˥塼ܤο" },
	{ N_MSG_ATTR_MAP_ITEM,
		"ƥο" },
	{ N_MSG_ATTR_MAP_SQUARE,
		STR_SQUARE "ο" },
	{ N_MSG_ATTR_MAP_MNSTR,
		"󥹥ο" },
	{ N_MSG_ATTR_MAP_CRSR,
		"ο" },
	{ N_MSG_ATTR_FX_MBR_PLUS,
		"Сβο" },
	{ N_MSG_ATTR_FX_MBR_MINUS,
		"СؤΥ᡼ο" },
	{ N_MSG_ATTR_FX_MBR_CRTCL,
		"СؤΥƥο" },
	{ N_MSG_ATTR_FX_MNSTR_PLUS,
		"󥹥βο" },
	{ N_MSG_ATTR_FX_MNSTR_MINUS,
		"󥹥ؤΥ᡼ο" },
	{ N_MSG_ATTR_FX_MNSTR_CRTCL,
		"󥹥ؤΥƥο" },
	{ N_MSG_ATTR_VFX,
		"եȤο" },
	{ N_MSG_ATTR_MBR_1,
		"Сο 1" },
	{ N_MSG_ATTR_MBR_2,
		"Сο 2" },
	{ N_MSG_ATTR_MBR_3,
		"Сο 3" },
	{ N_MSG_ATTR_MBR_4,
		"Сο 4" },
	{ N_MSG_ATTR_MBR_5,
		"Сο 5" },
	{ N_MSG_ATTR_MBR_6,
		"Сο 6" },

/* color end */

/* menu begin */

	{ N_MSG_MENU_FRAME,
		"----------------------------------------"
		"----------------------------------------" },
	{ N_MSG_MENU_CLR_FMT,
		"% *s" },
	{ N_MSG_MENU_SELECT_FMT,
		"*%s%s%-*s%*s%*s*" },
	{ N_MSG_MENU_NOT_SELECT_FMT,
		" %s%s%-*s%*s%*s " },
	{ N_MSG_MENU_CONTENTS_FMT,
		"%s%*s" },
	{ N_MSG_MENU_FLG_LS_CHK_ON,
		"[*]" },
	{ N_MSG_MENU_FLG_LS_CHK_OFF,
		"[ ]" },
	{ N_MSG_MENU_FLG_LS_CHK_NULL,
		"   " },
	{ N_MSG_MENU_ACCEL_KEY_FMT,
		"(%s)" },
	{ N_MSG_MENU_DIRECT_FMT,
		"%c)" },
	{ N_MSG_MENU_H_LINE,
		"-" },
	{ N_MSG_MENU_V_LINE,
		"|" },
	{ N_MSG_MENU_LEFT,
		"+---" },
	{ N_MSG_MENU_LEFT_PREV,
		"+<<=" },
	{ N_MSG_MENU_RIGHT,
		"---+" },
	{ N_MSG_MENU_RIGHT_NEXT,
		"=>>+" },
	{ N_MSG_MENU_CORNER,
		"+" },
	{ N_MSG_MENU_KIND_BRANCH,
		" >" },
	{ N_MSG_MENU_KIND_OPEN_WIN_ITEM,
		"..." },
	{ N_MSG_MENU_KIND_ITEM,
		"" },

	{ N_MSG_MENU_YES,
		"Ϥ" },
	{ N_MSG_MENU_NO,
		"" },

	{ N_MSG_MENU_MIN,
		"[min]" },
	{ N_MSG_MENU_MAX,
		"[max]" },
	{ N_MSG_MENU_OK,
		"[ok]" },

	{ N_MSG_MENU_DUP_ACCEL_KEY,
		"졼νʣ: '%s' (%s)" },

	{ N_MSG_TTL_MENU_MAIN_RACE,
		"²" },
	{ N_MSG_TTL_MENU_SUB_RACE,
		"ݤ碌" },
	{ N_MSG_TTL_MENU_SEX,
		"" },
	{ N_MSG_TTL_MENU_CLASS,
		"饹" },

/* main menu */

	{ N_MSG_MENU_EXEC,
		"Execute" },
	{ N_MSG_MENU_MARK,
		"Mark" },
	{ N_MSG_MENU_MOVE,
		"Move" },
	{ N_MSG_MENU_SPELL,
		"Cast" },
	{ N_MSG_MENU_FIGHT,
		"Fight" },
	{ N_MSG_MENU_ITEM,
		"Item" },
	{ N_MSG_MENU_EQUIP,
		"Equipment" },
	{ N_MSG_MENU_MISC,
		"Miscellaneous" },

/* menu mark begin */

	{ N_MSG_MENU_POINT_CRSR,
		"ޡΤǲ" },

	{ N_MSG_MENU_SEL_OBJ_MBR,
		"Member" },
	{ N_MSG_MENU_SEL_OBJ_SQUARE,
		STR_SQUARE },
	{ N_MSG_MENU_SEL_OBJ_ITEM,
		"Item" },
	{ N_MSG_MENU_SEL_OBJ_MNSTR,
		"Monster" },
	{ N_MSG_MENU_SEL_OBJ_DOOR,
		"Door" },
	{ N_MSG_MENU_SEL_OBJ_TRAP,
		"Trap" },
	{ N_MSG_MENU_SEL_OBJ_POS,
		"Position" },
	{ N_MSG_MENU_SEL_OBJ_CLEAR,
		"Clear" },
	{ N_MSG_MENU_SEL_OBJ_AUTO,
		"Auto" },

	{ N_MSG_MENU_DIST_NEAR,
		"Near" },
	{ N_MSG_MENU_DIST_MEDIUM,
		"Medium" },
	{ N_MSG_MENU_DIST_FAR,
		"Far" },

	{ N_MSG_MENU_MARK_FIGHT,
		"Fight" },
	{ N_MSG_MENU_MARK_THROW,
		"Throw" },
	{ N_MSG_MENU_MARK_TAIL,
		"Tail" },

	{ N_MSG_MENU_MARK_ITEM_PICK_UP,
		"Pick up" },
	{ N_MSG_MENU_MARK_ITEM_OPEN,
		"Open" },
	{ N_MSG_MENU_MARK_ITEM_DISARM,
		STR_DISARM },
	{ N_MSG_MENU_MARK_ITEM_BREAK,
		"Break" },
	{ N_MSG_MENU_MARK_ITEM_SRCH,
		"Detect" },

	{ N_MSG_MENU_MARK_DOOR_OPEN,
		"Open" },
	{ N_MSG_MENU_MARK_DOOR_CLOSE,
		"Close" },
	{ N_MSG_MENU_MARK_DOOR_JAM,
		"Spike" },
	{ N_MSG_MENU_MARK_DOOR_DISARM,
		STR_DISARM },
	{ N_MSG_MENU_MARK_DOOR_BREAK,
		"Break" },
	{ N_MSG_MENU_MARK_DOOR_PEEP,
		"Peep keyhole" },
	{ N_MSG_MENU_MARK_DOOR_SRCH,
		"Detect" },

	{ N_MSG_MENU_MARK_TRAP_DISARM,
		STR_DISARM },
	{ N_MSG_MENU_MARK_TRAP_BREAK,
		"Break" },
	{ N_MSG_MENU_MARK_TRAP_SRCH,
		"Detect" },

	{ N_MSG_MENU_MARK_SQUARE_POS,
		"ꤷƲ" },

/* menu mark end */

/* menu select item begin */

	{ N_MSG_MENU_ITEM_LS_EQUIP,
		"" },

	{ N_MSG_MENU_ITEM_QUAFF,
		"Quaff" },
	{ N_MSG_MENU_ITEM_READ,
		"Read" },
	{ N_MSG_MENU_ITEM_ZAP,
		"Zap" },
	{ N_MSG_MENU_ITEM_EAT,
		"Eat" },
	{ N_MSG_MENU_ITEM_SMOKE,
		"Smoke" },
	{ N_MSG_MENU_ITEM_FILL_LAMP,
		"Fill lamp" },
	{ N_MSG_MENU_ITEM_EQUIP,
		"Equip" },
	{ N_MSG_MENU_ITEM_READY_THROW,
		"Ready throw" },
	{ N_MSG_MENU_ITEM_SEND,
		"Send" },
	{ N_MSG_TTL_MENU_ITEM_SEND,
		"ïϤ?" },
	{ N_MSG_MENU_ITEM_DROP,
		"Drop" },
	{ N_MSG_MENU_ITEM_SRCH,
		"Detect" },

	{ N_MSG_MENU_ITEM_RECEIVE,
		"Receive" },

/* menu select item end */

/* menu select equipment begin */

	{ N_MSG_MENU_SEL_EQUIP_WIELDING,
		STR_EQUIP_WIELDING },
	{ N_MSG_MENU_SEL_EQUIP_SHIELD,
		STR_EQUIP_SHIELD },
	{ N_MSG_MENU_SEL_EQUIP_BOW,
		STR_EQUIP_BOW },
	{ N_MSG_MENU_SEL_EQUIP_ARW,
		STR_EQUIP_ARW },
	{ N_MSG_MENU_SEL_EQUIP_HEAD,
		STR_EQUIP_HEAD },
	{ N_MSG_MENU_SEL_EQUIP_NECK,
		STR_EQUIP_NECK },
	{ N_MSG_MENU_SEL_EQUIP_BODY,
		STR_EQUIP_BODY },
	{ N_MSG_MENU_SEL_EQUIP_ARM,
		STR_EQUIP_ARM },
	{ N_MSG_MENU_SEL_EQUIP_RIGHT_HAND,
		STR_EQUIP_RIGHT_HAND },
	{ N_MSG_MENU_SEL_EQUIP_LEFT_HAND,
		STR_EQUIP_LEFT_HAND },
	{ N_MSG_MENU_SEL_EQUIP_FEET,
		STR_EQUIP_FEET },
	{ N_MSG_MENU_SEL_EQUIP_ABOUT_BODY,
		STR_EQUIP_ABOUT_BODY },
	{ N_MSG_MENU_SEL_EQUIP_LIGHT_SOURCE,
		STR_EQUIP_LIGHT_SOURCE },
	{ N_MSG_MENU_EQUIP_LS_ITEM,
		"List item" },

	{ N_MSG_MENU_EQUIP_WEAR,
		"Wear" },
	{ N_MSG_MENU_EQUIP_TAKE_OFF,
		"Take off" },

	{ N_MSG_MENU_EQUIP_WEAR_MBR,
		"Wear other" },
	{ N_MSG_MENU_EQUIP_TAKE_OFF_MBR,
		"Take off other" },

/* menu select equipment end */

/* menu misc begin */

	{ N_MSG_MENU_STAIRS,
		"Stairs" },
	{ N_MSG_MENU_SRCH,
		"Detect" },
	{ N_MSG_MENU_DATA,
		"Member data" },
	{ N_MSG_MENU_MNSTR_DATA,
		"Monster data" },
	{ N_MSG_MENU_SLEEP,
		"Sleep" },
	{ N_MSG_MENU_COLLECT_GOLD,
		"Collect GOLD" },
	{ N_MSG_MENU_DIVIDE_GOLD,
		"Divide GOLD" },
	{ N_MSG_MENU_MSG,
		"List Message" },
	{ N_MSG_MENU_OUT_MAP_FILE,
		"Output map" },
	{ N_MSG_MENU_SHELL,
		"Shell" },
	{ N_MSG_MENU_CNF,
		"Config" },
	{ N_MSG_MENU_WIZARD,
		"Wizard" },
	{ N_MSG_MENU_ABOUT_GAME,
		"About " STR_FILE_NAME_GAME },
	{ N_MSG_MENU_EXIT,
		"Exit" },

	{ N_MSG_MENU_STAIRS_UP,
		"Up Stairs" },
	{ N_MSG_MENU_STAIRS_DOWN,
		"Down Stairs" },

	{ N_MSG_TTL_MENU_SRCH,
		"Search" },
	{ N_MSG_MENU_SRCH_EXEC,
		"Execute" },
	{ N_MSG_MENU_SRCH_EXEC_ALL,
		"Execute (All member)" },
	{ N_MSG_MENU_SRCH_CANCEL_ALL,
		"Cancel (All member)" },
	{ N_MSG_MENU_SRCH_AUTO_OFF,
		"Auto off" },

	{ N_MSG_MNSTR_DATA_NAME,
		"%c%c is %s" },
	{ N_MSG_MNSTR_DATA_MAX_LEV,
		"Max Level of %c%c is %ld" },
	{ N_MSG_MNSTR_DATA_MIN_LEV,
		"Min Level of %c%c is %ld" },

/* menu cursor begin */

	{ N_MSG_MENU_CRSR,
		"Cursor" },

/* menu cursor move begin */

	{ N_MSG_MENU_CRSR_MOVE,
		"Move" },
	{ N_MSG_MENU_CRSR_MOVE_UP,
		"Up" },
	{ N_MSG_MENU_CRSR_MOVE_DOWN,
		"Down" },
	{ N_MSG_MENU_CRSR_MOVE_LEFT,
		"Left" },
	{ N_MSG_MENU_CRSR_MOVE_RIGHT,
		"Right" },
	{ N_MSG_MENU_CRSR_MOVE_UP_LEFT,
		"Up Left" },
	{ N_MSG_MENU_CRSR_MOVE_UP_RIGHT,
		"Up Right" },
	{ N_MSG_MENU_CRSR_MOVE_DOWN_LEFT,
		"Down Left" },
	{ N_MSG_MENU_CRSR_MOVE_DOWN_RIGHT,
		"Down Right" },

/* menu cursor move end */

/* menu cursor quick move begin */

	{ N_MSG_MENU_CRSR_QUICK_MOVE,
		"٤ޤǰư" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_UP,
		"Up" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_DOWN,
		"Down" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_LEFT,
		"Left" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_RIGHT,
		"Right" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_UP_LEFT,
		"Up Left" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_UP_RIGHT,
		"Up Right" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_DOWN_LEFT,
		"Down Left" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_DOWN_RIGHT,
		"Down Right" },

/* menu cursor quick move end */

	{ N_MSG_MENU_CRSR_SCROLL_CENTER,
		"󥿥" },
	{ N_MSG_MENU_CRSR_NEXT_POS_MBR,
		"Next Member" },
	{ N_MSG_MENU_CRSR_NEXT_POS_MNSTR,
		"Next Monster" },
	{ N_MSG_MENU_CRSR_NEXT_POS_ITEM,
		"Next Item" },
	{ N_MSG_MENU_CRSR_NEXT_POS_DOOR,
		"Next Door" },
	{ N_MSG_MENU_CRSR_NEXT_POS_OBJ,
		"Next Object" },
	{ N_MSG_MENU_CRSR_NEXT_POS_SQUARE,
		"Next " STR_SQUARE },
	{ N_MSG_MENU_CRSR_NEXT_POS_ALL,
		"Next" },
	{ N_MSG_MENU_CRSR_PREV_POS,
		"Previous" },

/* menu cursor end */

/* menu config begin */

	{ N_MSG_MENU_AUTO_FIGHT,
		"󥹥ˤ֤Ĥä鹶⤹" },
	{ N_MSG_MENU_AUTO_DOOR,
		"ɥưŪ˳" },
	{ N_MSG_MENU_AVOID_TRAP,
		"櫤򤱤" },
	{ N_MSG_MENU_AUTO_RELOAD,
		"ưŶ" },
	{ N_MSG_MENU_SCROLL_PAGE,
		"ڡ" },
	{ N_MSG_MENU_SCROLL_SMOOTH,
		"ࡼ" },
	{ N_MSG_MENU_SCROLL_CENTER,
		"ࡼ(濴)" },
	{ N_MSG_MENU_MUL_MSG_LINE,
		"åԤʣ" },
	{ N_MSG_MENU_VFX,
		"и" },
	{ N_MSG_MENU_COLOR,
		"ɽ" },
	{ N_MSG_MENU_CRSR_PTN,
		"η" },

	{ N_MSG_MENU_VFX_MBR_HP_ADD,
		"СHPβ" },
	{ N_MSG_MENU_VFX_MBR_HP_SUB,
		"СHPΥ᡼" },
	{ N_MSG_MENU_VFX_MBR_HP_SUB_CRTCL,
		"СHPΥƥ롦᡼" },
	{ N_MSG_MENU_VFX_MBR_ARW,
		"Сƻ" },
	{ N_MSG_MENU_VFX_MNSTR_HP_ADD,
		"󥹥HPβ" },
	{ N_MSG_MENU_VFX_MNSTR_HP_SUB,
		"󥹥HPΥ᡼" },
	{ N_MSG_MENU_VFX_MNSTR_HP_SUB_CRTCL,
		"󥹥HPΥƥ롦᡼" },
	{ N_MSG_MENU_VFX_MNSTR_ARW,
		"󥹥ƻ" },
	{ N_MSG_MENU_VFX_WAIT,
		"[%ld]" },

	{ N_MSG_MENU_FG,
		"ʿ" },
	{ N_MSG_MENU_BG,
		"طʿ" },
	{ N_MSG_MENU_COLOR_BLACK,
		"" },
	{ N_MSG_MENU_COLOR_RED,
		"" },
	{ N_MSG_MENU_COLOR_GREEN,
		"" },
	{ N_MSG_MENU_COLOR_YELLOW,
		"" },
	{ N_MSG_MENU_COLOR_BLUE,
		"" },
	{ N_MSG_MENU_COLOR_MAGENTA,
		"" },
	{ N_MSG_MENU_COLOR_CYAN,
		"忧" },
	{ N_MSG_MENU_COLOR_WHITE,
		"" },

	{ N_MSG_MENU_ATTR,
		"°" },
	{ N_MSG_MENU_UNDERLINE,
		"" },
	{ N_MSG_MENU_REVERSE,
		"ȿž" },
	{ N_MSG_MENU_BLINK,
		"" },
	{ N_MSG_MENU_BOLD,
		"Ĵ" },

	{ N_MSG_MENU_CRSR_PTN_SEL,
		"ֹϤƲ" },

/* menu config end */

	{ N_MSG_TTL_MENU_EXIT,
		"֤˽λޤ?" },

/* menu wizard begin */

	{ N_MSG_TTL_MENU_WIZARD,
		"" },
	{ N_MSG_MENU_WIZARD_ON_LIGHT,
		"" },
	{ N_MSG_MENU_WIZARD_OFF_LIGHT,
		"ä" },

/* menu wizard end */

/* menu misc end */

/* menu auto mark begin */

	{ N_MSG_MENU_AUTO_MARK_TITLE,
		"ưޡ" },
	{ N_MSG_MENU_AUTO_MARK_EXEC,
		"¹" },
	{ N_MSG_MENU_AUTO_MARK_EDIT,
		"Խ" },
	{ N_MSG_MENU_AUTO_MARK_ARRANGE,
		"Ƭ¤ٴ" },
	{ N_MSG_MENU_AUTO_MARK_INVALID,
		"----" },

	{ N_MSG_TTL_MENU_AUTO_MARK_EDIT,
		"(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_TRGT,
		"о   : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_DIST,
		"ֹ礤 : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_ACT,
		"ư   : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_COND,
		"   : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_APPOINT_ITEM,
		"ƥ" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_CONT,
		"Ϣ³ޡ" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_PRIORITY,
		"ߤͥ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_TRGT,
		"о(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_MNSTR,
		"󥹥" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_ITEM,
		"ƥ" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_DOOR,
		"ɥ" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_TRAP,
		"ȥå" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_MBR,
		"С" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_UNCHANGE,
		"ѹʤ" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_CLEAR,
		"ޡ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_DIST,
		"ֹ礤(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_DIST_NEAR,
		"" },
	{ N_MSG_MENU_AUTO_MARK_DIST_MEDIUM,
		"" },
	{ N_MSG_MENU_AUTO_MARK_DIST_FAR,
		"Υ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_ACT,
		"ư(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_ACT_FIGHT,
		"臘" },
	{ N_MSG_MENU_AUTO_MARK_ACT_THROW,
		"ꤲ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_TAIL,
		"ɤ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_SRCH,
		"Ĵ٤" },
	{ N_MSG_MENU_AUTO_MARK_ACT_PICK_UP,
		"Ҥ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_BREAK,
		"" },
	{ N_MSG_MENU_AUTO_MARK_ACT_OPEN,
		"" },
	{ N_MSG_MENU_AUTO_MARK_ACT_CLOSE,
		"Ĥ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_JAM,
		"ꤹ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_DISARM,
		STR_DISARM "" },
	{ N_MSG_MENU_AUTO_MARK_ACT_PEEP,
		"Τ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_COND,
		"(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_COND_NEAREST,
		"ֶᤤ" },
	{ N_MSG_MENU_AUTO_MARK_COND_DISPERSE,
		"Ф餱" },
	{ N_MSG_MENU_AUTO_MARK_COND_STAGGER,
		"Ƥ" },
	{ N_MSG_MENU_AUTO_MARK_COND_OWN,
		"äƤ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
		"ƥ(%s) - %s" },
	{ N_MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MNR,
		"ƥܺ(%s) - %s" },

	{ N_MSG_NAME_DFLT_AUTO_MARK_FIGHT,
		"Ʈ" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
		"Ʈ()" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
		"ƤΥƥ" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
		"äƤ륢ƥ" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_CLEAR,
		"" },

/* menu auto mark end */

/* menu town begin */

	{ N_MSG_MENU_SHOP_SEL_MBR,
		"%s ï?" },

	{ N_MSG_BUY,
		"㤦" },
	{ N_MSG_SALE_ITEM,
		"ƥ" },
	{ N_MSG_SALE_EQUIP,
		"" },

	{ N_MSG_CAN_USE_ITEM_YES,
		"o: " },
	{ N_MSG_CAN_USE_ITEM_REST,
		" : " },
	{ N_MSG_CAN_USE_ITEM_NO,
		"x: " },
	{ N_MSG_CAN_USE_ITEM_ERR,
		"?: " },

	{ N_MSG_MENU_BUY,
		"%s 㤤ޤ?" },
	{ N_MSG_MENU_SALE,
		"%s ޤ?" },
	{ N_MSG_TTL_MENU_BUY,
		"㤤ޤ?" },
	{ N_MSG_TTL_MENU_SALE,
		"ޤ?" },
	{ N_MSG_MENU_REACHED_BUY,
		"%s 㤤ޤ" },
	{ N_MSG_MENU_REACHED_SALE,
		"%s ޤ" },

	{ N_MSG_FMT_MENU_SHOP,
		"%s %s %s %ld " STR_GOLD },
	{ N_MSG_MENU_SHOP_DATA,
		"ǽ" },
	{ N_MSG_MENU_SHOP_COLLECT_GOLD,
		"򽸤" },
	{ N_MSG_MENU_SHOP_DIVIDE_GOLD,
		"ʬۤ" },
	{ N_MSG_MENU_SHOP_BUY,
		"㤦" },
	{ N_MSG_MENU_SHOP_SALE_ITEM,
		"ʪ" },
	{ N_MSG_MENU_SHOP_SALE_EQUIP,
		"" },

	{ N_MSG_TTL_MENU_TEMPLE,
		"%s %s %ld " STR_GOLD },
	{ N_MSG_FMT_MENU_TEMPLE,
		"%-*s %4ld " STR_GOLD },
	{ N_MSG_MENU_TEMPLE_REMOVE_CURSE,
		"" },
	{ N_MSG_MENU_TEMPLE_CURE_STATUS,
		"ֲ" },
	{ N_MSG_MENU_TEMPLE_RESURRECTION,
		"" },
	{ N_MSG_MENU_TEMPLE_CONTRIBUTION,
		"" },

	{ N_MSG_TTL_MENU_TEMPLE_REMOVE_CURSE,
		"ޤ?" },
	{ N_MSG_TTL_MENU_TEMPLE_CURE_STATUS,
		"ֲޤ?" },
	{ N_MSG_TTL_MENU_TEMPLE_RESURRECTION,
		"褷ޤ?" },
	{ N_MSG_TTL_MENU_TEMPLE_CONTRIBUTION,
		"դޤ?" },

	{ N_MSG_MENU_REMOVE_CURSE,
		"%s μϲ򤱤" },
	{ N_MSG_MENU_REMOVE_CURSE_ERR,
		"%s ϼƤޤ" },
	{ N_MSG_MENU_CURE_STATUS,
		"%s ξ֤ϲ" },
	{ N_MSG_MENU_CURE_STATUS_ERR,
		"%s ξ֤ϰޤ" },
	{ N_MSG_TTL_MENU_RESURRECTION,
		"ïޤ?" },
	{ N_MSG_MENU_RESURRECTION_ERR_ALL_MBR,
		"ïǤޤ" },
	{ N_MSG_MENU_RESURRECTION,
		"%s ֤ä" },
	{ N_MSG_MENU_RESURRECTION_FAILURE,
		"%s ֤ʤä" },
	{ N_MSG_MENU_RESURRECTION_ERR,
		"%s ϻǤޤ" },
	{ N_MSG_MENU_CONTRIBUTION,
		"%s  %ld " STR_GOLD " դ" },

	{ N_MSG_MENU_BAR_FORM,
		"ѡƥ" },

	{ N_MSG_MENU_BAR_EDIT_MBR,
		"СԽ" },
	{ N_MSG_MENU_BAR_NEW_MBR,
		"СϿ" },
	{ N_MSG_MENU_BAR_REMOVE_MBR,
		"С" },

	{ N_MSG_MENU_BAR_EDIT_CLASS,
		"饹Խ" },
	{ N_MSG_MENU_BAR_NEW_CLASS,
		"饹Ͽ" },
	{ N_MSG_MENU_BAR_REMOVE_CLASS,
		"饹" },

	{ N_MSG_MENU_BAR_SAVE,
		"" },

	{ N_MSG_TTL_MENU_BAR_FORM,
		"ѡƥ" },
	{ N_MSG_MENU_BAR_JOIN,
		"ѡƥ˲ä" },
	{ N_MSG_MENU_BAR_NOT_JOIN,
		"ѡƥ鳰" },

	{ N_MSG_TTL_MENU_BAR_EDIT_MBR,
		"СԽ" },
	{ N_MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
		"%s 򥨥ǥå" },
	{ N_MSG_MENU_BAR_ARRANGE,
		"Ƭ¤ٴ" },
	{ N_MSG_TTL_MENU_BAR_REMOVE_MBR,
		"С" },

	{ N_MSG_TTL_MENU_ASK_EDIT_MBR,
		"ѹ¸ޤ?" },
	{ N_MSG_TTL_MENU_ASK_NEW_MBR,
		"ǥСϿޤ?" },
	{ N_MSG_TTL_MENU_ASK_REMOVE_MBR,
		"˥Сޤ?" },

	{ N_MSG_MENU_REMOVE_MBR_NAME,
		"%s ޤ" },
	{ N_MSG_MENU_REMOVE_MBR_LEV,
		"ǹ٥ %ld Ǥ" },
	{ N_MSG_MENU_REMOVE_MBR_GOLD,
		"%ld " STR_GOLD " Ƥޤ" },

	{ N_MSG_TTL_MENU_ASK_EDIT_CLASS,
		"ѹ¸ޤ?" },
	{ N_MSG_TTL_MENU_ASK_NEW_CLASS,
		"ǥ饹Ͽޤ?" },
	{ N_MSG_TTL_MENU_ASK_REMOVE_CLASS,
		"˥饹ޤ?" },

	{ N_MSG_MENU_NEW_MBR,
		"New Character" },
	{ N_MSG_MENU_NEW_CLASS,
		"New Class" },

	{ N_MSG_MENU_INN_STAY,
		"ޤ %8ld " STR_GOLD },
	{ N_MSG_MENU_INN_DO_STAY,
		"񤷤īˤʤä" },

/* menu town end */

/* menu spell begin */

	{ N_MSG_SPELL_EXTENT_NORMAL,
		"̾" },
	{ N_MSG_SPELL_EXTENT_SPREAD,
		"Ȼ" },
	{ N_MSG_SPELL_EXTENT_MASS,
		"" },
	{ N_MSG_SPELL_EXTENT_HALF,
		"Ⱦ" },

/* menu spell end */

/* menu end */

	{ N_MSG_MBR_DATA_SEL,
		"*%s*" },
	{ N_MSG_MBR_DATA_NOT_SEL,
		" %s " },

	{ N_MSG_GETS_MBR_NAME,
		"̾ϤƲ(%ld ʸ)" },
	{ N_MSG_GETS_MBR_FACE,
		"ʸʸϤƲ" },
	{ N_MSG_GETS_RACE_NAME,
		"²̾ϤƲ(%ld ʸ)" },

	{ N_MSG_RACE_STR_PUREBRED,
		"%sν" },
	{ N_MSG_RACE_STR_MIXED,
		"%s & %s" },

	{ N_MSG_MBR_DATA_NAME_TTL,
		"̾  : " },
	{ N_MSG_MBR_DATA_FACE_TTL,
		"    : " },
	{ N_MSG_MBR_DATA_RACE_STR_TTL,
		"²  : " },
	{ N_MSG_MBR_DATA_RACE_NAME_TTL,
		"²̾: " },
	{ N_MSG_MBR_DATA_SEX_TTL,
		"  : " },

	{ N_MSG_MBR_DATA_HP_VAL,
		"HP: " },
	{ N_MSG_MBR_DATA_MP_VAL,
		"MP: " },

	{ N_MSG_MBR_DATA_VAL_TTL,
		"                     ()" },
	{ N_MSG_MBR_DATA_HIT_TTL,
		"            : " },
	{ N_MSG_MBR_DATA_HIT,
		"%s%4ld (%4ld)" },
	{ N_MSG_MBR_DATA_WPN_CRTCL_TTL,
		"ƥ빶: " },
	{ N_MSG_MBR_DATA_WPN_CRTCL,
		"%s%4ld (%4ld)" },
	{ N_MSG_MBR_DATA_DAM_TTL,
		"᡼          : " },
	{ N_MSG_MBR_DATA_DAM,
		"%s%4ld (%4ld)" },
	{ N_MSG_MBR_DATA_DEF_TTL,
		"ɸ            : " },
	{ N_MSG_MBR_DATA_DEF,
		"%s%4ld" },
	{ N_MSG_MBR_DATA_ARMOR_CRTCL_TTL,
		"ƥɸ: " },
	{ N_MSG_MBR_DATA_ARMOR_CRTCL,
		"%s%4ld" },
	{ N_MSG_MBR_DATA_AC_TTL,
		"ޡ饹    : " },
	{ N_MSG_MBR_DATA_AC,
		"%s%4ld" },

	{ N_MSG_MBR_DATA_GOLD_TTL,
		STR_GOLD ": " },
	{ N_MSG_CALENDAR,
		"%ldǯ%ld%ld%ld%ldʬ" },

	{ N_MSG_MBR_DATA_STAT_TTL,
		":" },
	{ N_MSG_MBR_DATA_STAT_NULL,
		"[    ]" },
	{ N_MSG_MBR_DATA_STAT_DEAD,
		"[˴]" },
	{ N_MSG_MBR_DATA_STAT_STONE,
		"[в]" },
	{ N_MSG_MBR_DATA_STAT_PARALYZE,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_POISON,
		"[  ]" },
	{ N_MSG_MBR_DATA_STAT_CONFUSION,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_BLIND,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_SLEEP,
		"[̲]" },
	{ N_MSG_MBR_DATA_STAT_SILENCE,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_FEAR,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_HALLUCINATION,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_CHARM,
		"[̥λ]" },
	{ N_MSG_MBR_DATA_STAT_FLY,
		"[ͷ]" },
	{ N_MSG_MBR_DATA_STAT_HUNGRY,
		"[ʢ]" },
	{ N_MSG_MBR_DATA_STAT_STARVATION,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_FAINT,
		"[ޤ]" },
	{ N_MSG_MBR_DATA_STAT_DRUNK,
		"[줤]" },

	{ N_MSG_MBR_DATA_LEV_TTL,
		"٥" },
	{ N_MSG_MBR_DATA_EXP_TTL,
		"и" },
	{ N_MSG_MBR_DATA_NEED_EXP_TTL,
		"ɬ׷и" },

	{ N_MSG_FMT_MBR_DATA_ABL,
		"%5s%s%2ld %-3s %10ld/%10ld%s" },
	{ N_MSG_FMT_MBR_DATA_VALUE,
		"%4ld" },
	{ N_MSG_FMT_MBR_DATA_ADD_LEV,
		"%+2ld" },
	{ N_MSG_MBR_DATA_HP_TTL,
		"HP : " },
	{ N_MSG_MBR_DATA_MP_TTL,
		"MP : " },
	{ N_MSG_MBR_DATA_DEX_TTL,
		"DEX: " },
	{ N_MSG_MBR_DATA_STR_TTL,
		"STR: " },
	{ N_MSG_MBR_DATA_AGI_TTL,
		"AGI: " },
	{ N_MSG_MBR_DATA_WIS_TTL,
		"WIS: " },
	{ N_MSG_MBR_DATA_INT_TTL,
		"INT: " },
	{ N_MSG_MBR_DATA_CHA_TTL,
		"CHA: " },
	{ N_MSG_MBR_DATA_FIG_TTL,
		"FIG: " },
	{ N_MSG_MBR_DATA_MON_TTL,
		"MON: " },
	{ N_MSG_MBR_DATA_HUN_TTL,
		"HUN: " },
	{ N_MSG_MBR_DATA_THI_TTL,
		"THI: " },
	{ N_MSG_MBR_DATA_MAG_TTL,
		"MAG: " },
	{ N_MSG_MBR_DATA_SOR_TTL,
		"SOR: " },
	{ N_MSG_MBR_DATA_ENC_TTL,
		"ENC: " },
	{ N_MSG_MBR_DATA_SUM_TTL,
		"SUM: " },
	{ N_MSG_MBR_DATA_PRI_TTL,
		"PRI: " },
	{ N_MSG_MBR_DATA_SHA_TTL,
		"SHA: " },
	{ N_MSG_MBR_DATA_BAR_TTL,
		"BAR: " },
	{ N_MSG_MBR_DATA_NIN_TTL,
		"NIN: " },

	{ N_MSG_FMT_MBR_DATA_RESI,
		"%s%3ld%" },
	{ N_MSG_MBR_DATA_RESI_TTL,
		"---- " },
	{ N_MSG_MBR_DATA_RESI_KNOC_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_SLAS_TTL,
		"·: " },
	{ N_MSG_MBR_DATA_RESI_STIN_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_HEAT_TTL,
		"Ǯ: " },
	{ N_MSG_MBR_DATA_RESI_COLD_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_WIND_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_ACID_TTL,
		"ڻ: " },
	{ N_MSG_MBR_DATA_RESI_ELEC_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_POIS_TTL,
		": " },

	{ N_MSG_MBR_DATA_CLASS_TTL,
		"饹: " },
	{ N_MSG_MBR_DATA_CLASS,
		"%s%s" },

	{ N_MSG_MBR_DATA_NEXT_PAGE,
		"Υڡ" },

	{ N_MSG_LEV_UP_LEFT_OFF,
		" " },
	{ N_MSG_LEV_UP_RIGHT_OFF,
		" " },
	{ N_MSG_LEV_UP_LEFT_ON,
		"*" },
	{ N_MSG_LEV_UP_RIGHT_ON,
		"*" },

/* edit class begin */

	{ N_MSG_EDIT_CLASS_TTL,
		"%s%3ld%%" },
	{ N_MSG_EDIT_CLASS_ADD_SEL,
		"<+>" },
	{ N_MSG_EDIT_CLASS_ADD_NOT_SEL,
		" + " },
	{ N_MSG_EDIT_CLASS_SUB_SEL,
		"<->" },
	{ N_MSG_EDIT_CLASS_SUB_NOT_SEL,
		" - " },
	{ N_MSG_EDIT_CLASS_TOTAL,
		"TOTAL: %3ld" },
	{ N_MSG_EDIT_CLASS_NAME,
		"%s%-*s" },
	{ N_MSG_EDIT_CLASS_PREV,
		"Υ饹" },
	{ N_MSG_EDIT_CLASS_NEXT,
		"Υ饹" },

/* edit class end */

	{ N_MSG_FMT_MSG,
		"%-*s" },
	{ N_MSG_FMT_WPN_IDENTIFIED,
		"%2ld %s(%+ld,%+ld,%+ld)" },
	{ N_MSG_FMT_WPN_SLAYER,
		"%2ld %s %c 쥤䡼"
		"(%+ld,%+ld,%+ld)" },
	{ N_MSG_FMT_WPN_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_ARMOR_IDENTIFIED,
		"%2ld %s[%+ld,%+ld,%+ld]" },
	{ N_MSG_FMT_ARMOR_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_POTION_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_POTION_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_SCROLL_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_SCROLL_NOT_IDENTIFIED,
		"%2ld %sδʪ" },
	{ N_MSG_FMT_WAND_IDENTIFIED,
		"%2ld %sΥ(%ld)" },
	{ N_MSG_FMT_ROD_IDENTIFIED,
		"%2ld %sΥå(%ld)" },
	{ N_MSG_FMT_STAFF_IDENTIFIED,
		"%2ld %sΥå(%ld)" },
	{ N_MSG_FMT_WAND_NOT_IDENTIFIED,
		"%2ld %sΥ" },
	{ N_MSG_FMT_ROD_NOT_IDENTIFIED,
		"%2ld %sΥå" },
	{ N_MSG_FMT_STAFF_NOT_IDENTIFIED,
		"%2ld %sΥå" },
	{ N_MSG_FMT_ACCE_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_RING_NOT_IDENTIFIED,
		"%2ld %sλ" },
	{ N_MSG_FMT_AMULET_NOT_IDENTIFIED,
		"%2ld %sθ" },
	{ N_MSG_FMT_NECKLACE_NOT_IDENTIFIED,
		"%2ld %sμ" },
	{ N_MSG_FMT_LIGHT_IDENTIFIED,
		"%2ld %s %ld" },
	{ N_MSG_FMT_LIGHT_NOT_IDENTIFIED,
		"%2ld %s %ld" },
	{ N_MSG_FMT_SPIKE_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_SPIKE_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_FOOD_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_FOOD_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_CHEST_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_CHEST_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_TOBACCO_IDENTIFIED,
		"%2ld %s(%s: %ld)" },
	{ N_MSG_FMT_TOBACCO_NOT_IDENTIFIED,
		"%2ld %s(%s)" },
	{ N_MSG_FMT_TOBACCO_STUB_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_PIPE_IDENTIFIED,
		"%2ld %s(%ld)" },
	{ N_MSG_FMT_PIPE_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_PIPE_STUB_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_COIN_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_COIN_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_JUNK_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_JUNK_NOT_IDENTIFIED,
		"%2ld %s" },

	{ N_MSG_FMT_ART_NAME,
		"%-*s %8ld " STR_GOLD },
	{ N_MSG_FMT_IDENTIFY_ITEM,
		" %s " },
	{ N_MSG_FMT_MARK_MNSTR,
		"%s  %s ޡ" },
	{ N_MSG_FMT_ART_NAME_EQUIP,
		"%s%s:%s" },

	{ N_MSG_ERR_DOOR_OPEN_JAMMED,
		"ɥꤵƤƳޤ" },
	{ N_MSG_ERR_DOOR_CLOSE_JAMMED,
		"ɥꤵƤĤޤ" },
	{ N_MSG_ERR_DOOR_CLOSE_BROKEN,
		"ɥƤĤޤ" },
	{ N_MSG_ERR_DOOR_JAM_SPIKE,
		"%s äƤޤ" },
	{ N_MSG_ERR_DOOR_JAM_BROKEN,
		"ɥƤƸޤ" },
	{ N_MSG_ERR_DOOR_JAM_JAMMED,
		"ɥϸꤵƤޤ" },
	{ N_MSG_ERR_DOOR_DISARM_NOT_JAM,
		"ɥϸꤵƤޤ" },
	{ N_MSG_ERR_DOOR_DISARM_BROKEN,
		"ɥϲƤޤ" },
	{ N_MSG_ERR_DOOR_DISARM_LEV,
		"ɥ" STR_DISARM "˼Ԥ" },
	{ N_MSG_ERR_DOOR_BREAK_SHOP,
		"ʤȤ򤷤ܤޤ" },
	{ N_MSG_ERR_DOOR_BREAK_BROKEN,
		"ɥϴ˲Ƥޤ" },
	{ N_MSG_ERR_DOOR_BREAK_LEV,
		"ɥޤǤ" },

	{ N_MSG_ERR_TRAP_DISARM_LEV,
		"櫤" STR_DISARM "˼Ԥ" },
	{ N_MSG_ERR_TRAP_BREAK_LEV,
		"櫤ޤǤ" },

	{ N_MSG_ERR_ITEM_DISARM_LEV,
		"ƥ" STR_DISARM "˼Ԥ" },

	{ N_MSG_ERR_STAIRS,
		"Сʤ¦ˤޤ" },
	{ N_MSG_ERR_STAIRS_UP,
		"С곬ʤ¦ˤޤ" },
	{ N_MSG_ERR_STAIRS_DOWN,
		"С곬ʤ¦ˤޤ" },

	{ N_MSG_ERR_EQUIP_SEL_ITEM,
		"륢ƥबĤޤǤ" },

	{ N_MSG_ERR_CHK_KEY,
		"[%c: 0x%04x]̵ʥǤ" },

	{ N_MSG_ERR_MENU_SEL_ITEM,
		"%s κξ֤Ǥޤ" },
	{ N_MSG_ERR_MENU_SEL_EQUIP,
		"%s κξ֤Ǥޤ" },
	{ N_MSG_ERR_MENU_MARK_BLIND,
		"%s ܤʤΤǥޡޤ" },
	{ N_MSG_ERR_MENU_BAR_SEL_MBR,
		"ѡƥ˥СäƲ" },
	{ N_MSG_ERR_MENU_WANTING,
		"%s  %ld " STR_GOLD "­ޤ" },
	{ N_MSG_ERR_MENU_DATA_LEV_UP,
		"%s Ϸиͤ­ޤ" },

	{ N_MSG_ERR_MENU_EDIT_CLASS,
		"פ 100% ˤƲ" },
	{ N_MSG_ERR_MENU_NEW_CLASS,
		"ʾ奯饹ޤ" },
	{ N_MSG_ERR_REMOVE_CLASS,
		"ʾ奯饹Ǥޤ" },

	{ N_MSG_ERR_MENU_PAGE_OVER,
		"˥塼Υڡ¿ޤ" },
	{ N_MSG_ERR_MENU_SRCH_PATH,
		"˥塼θԤޤ'%s'" },
	{ N_MSG_ERR_ACCEL_KEY,
		"졼ʣƤޤ '%c':'%s'" },

	{ N_MSG_ERR_FILL_LAMP,
		"Ƥޤ" },
	{ N_MSG_ERR_FILL_LAMP_NON_OIL,
		"ʳ뤷" },
	{ N_MSG_ERR_THROW,
		"%s ꤲʪ̵ʤޤ" },
	{ N_MSG_ERR_MNSTR_NULL,
		"ˤϥ󥹥Ϥޤ" },
	{ N_MSG_ERR_NOT_FIND,
		"%s  %s ޤ" },
	{ N_MSG_ERR_ITEM_CURSE,
		"%s ϼƤƳޤ" },
	{ N_MSG_ERR_ITEM_FULL,
		"%s ϻʪäѤǤ" },
	{ N_MSG_ERR_ITEM_FLY,
		"%s ⤫ǤΤ %s 򽦤ޤ" },
	{ N_MSG_ERR_GIVE_MBR_ITEM,
		"%s ϻʪäѤ %s Ƥޤ" },
	{ N_MSG_ERR_GIVE_MBR_CHEST,
		"%s Ϥʾ %s ŤƻƤޤ" },
	{ N_MSG_ERR_ITEM_BREAK_BROKEN,
		"%s ϴ˲Ƥޤ" },
	{ N_MSG_ERR_ITEM_BREAK_LEV,
		"%s ޤǤ" },
	{ N_MSG_ERR_EQUIP_TWO_HANDED_WPN,
		"%s ξȽƱޤ" },

	{ N_MSG_ERR_POTION_COLOR,
		"ο̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_STICK_MATERIAL,
		"κ̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_RING_MATERIAL,
		"ؤκ̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_AMULET_MATERIAL,
		"κ̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_WPN_RATE_TAB,
		"ǡ۾Ǥ\n" },
	{ N_MSG_ERR_SET_TTY,
		"ü꤬ޤǤ\n" },
	{ N_MSG_ERR_HOME_DIR,
		"ۡࡦǥ쥯ȥ [%s] ꤬"
		"ޤǤ\n" },
	{ N_MSG_ERR_GAME_DIR_SAVE,
		"'%s'˽񤭹ޤǤ" },

	{ N_MSG_ERR_TOWN_MAP,
		"ޥåסǡ۾Ǥ\n" },
	{ N_MSG_ERR_TOWN_MAP_X_SIZE,
		"ޥåסǡοʿ㤤ޤ %ld/%ld" },
	{ N_MSG_ERR_TOWN_MAP_Y_SIZE,
		"ޥåסǡοľ㤤ޤ %ld/%ld" },
	{ N_MSG_ERR_TOWN_MAP_STR_LEN,
		"ޥåסǡοɽʸĹ"
		"12ʸˤƲ %ld" },
	{ N_MSG_ERR_TOWN_MAP_SHOP,
		"ޥåסǡäƤʤåפޤ\n" },

	/* Data Load */

	{ N_MSG_ERR_LOAD_WQUOTE,
		"'\"' ͭޤ" },
	{ N_MSG_ERR_LOAD_LINE_LEN,
		"Ԥʸ礤ޤ %ld/%ld" },
	{ N_MSG_ERR_LOAD_EOF,
		"ե뤬ڤƤޤ" },
	{ N_MSG_ERR_LOAD_TOWN_PTN,
		"Ťޥåסǡ '%s' Хååפޤ" },

	/* Data Save */

	{ N_MSG_ERR_SAVE_TOWN_PTN,
		"ޥåסǡֽޤǤ" },
	{ N_MSG_ERR_SAVE_CRSR_PTN,
		"롦ѥ󤬥ֽޤǤ" },

	{ N_MSG_WRN_RENAME,
		"ե̾ѹޤ\n\t'%s' ->\n\t'%s'" },
	{ N_MSG_WRN_CHK_ID,
		"ID:\n'%s'\n'%s'" },

	{ N_MSG_FMT_COPYRIGHT,
		STR_FMT_COPYRIGHT },
	{ N_MSG_ABOUT_GAME,
		"ܥץϥե꡼եȥǤ\n"
		"ʤϡ Free Software Foundation ɽ"
		" GNU ̸ͭѵΡ֥С󣲡"
		"ϤʹߤγƥС椫餤줫򤷡"
		"ΥС˽äܥץ"
		"ۤޤѹ뤳ȤǤޤ\n"
		"\n"
		"ܥץͭѤȤϻפޤۤˤäƤϡ"
		"ԾڤŪŬˤĤƤΰۤݾڤޤ,"
		"ʤݾڤԤʤޤ\n"
		"ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ\n"
		"\n"
		"ʤϡܥץȰ GNU ̸ͭѵ"
		"μ̤äƤϤǤǤʤϡ\n"
		"  Free Software Foundation, Inc.,\n"
		"  59 Temple Place, Suite 330, Boston, MA 02111-1307, USA\n"
		"ؼ񤤤Ƥ\n"
	},

#undef	STR_SQUARE

#undef	STR_EQUIP_WIELDING
#undef	STR_EQUIP_SHIELD
#undef	STR_EQUIP_BOW
#undef	STR_EQUIP_ARW
#undef	STR_EQUIP_HEAD
#undef	STR_EQUIP_NECK
#undef	STR_EQUIP_BODY
#undef	STR_EQUIP_ARM
#undef	STR_EQUIP_RIGHT_HAND
#undef	STR_EQUIP_LEFT_HAND
#undef	STR_EQUIP_FEET
#undef	STR_EQUIP_ABOUT_BODY
#undef	STR_EQUIP_LIGHT_SOURCE

#undef	STR_DISARM
#undef	STR_GOLD

#undef	STR_FIG
#undef	STR_MON
#undef	STR_HUN
#undef	STR_THI

#undef	STR_MAG
#undef	STR_SOR
#undef	STR_ENC
#undef	STR_SUM
#undef	STR_PRI
#undef	STR_SHA
#undef	STR_BAR
#undef	STR_NIN
